v1

package
v1.0.11 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 28, 2026 License: MIT Imports: 23 Imported by: 0

Documentation

Index

Constants

const (
	OrderService_CreateOrder_FullMethodName       = "/api.admin.order.v1.OrderService/CreateOrder"
	OrderService_GetOrderList_FullMethodName      = "/api.admin.order.v1.OrderService/GetOrderList"
	OrderService_UpdateOrderStatus_FullMethodName = "/api.admin.order.v1.OrderService/UpdateOrderStatus"
)
const OperationOrderServiceCreateOrder = "/api.admin.order.v1.OrderService/CreateOrder"
const OperationOrderServiceGetOrderList = "/api.admin.order.v1.OrderService/GetOrderList"
const OperationOrderServiceUpdateOrderStatus = "/api.admin.order.v1.OrderService/UpdateOrderStatus"

Variables

var File_admin_order_v1_order_proto protoreflect.FileDescriptor
var OrderService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "api.admin.order.v1.OrderService",
	HandlerType: (*OrderServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreateOrder",
			Handler:    _OrderService_CreateOrder_Handler,
		},
		{
			MethodName: "GetOrderList",
			Handler:    _OrderService_GetOrderList_Handler,
		},
		{
			MethodName: "UpdateOrderStatus",
			Handler:    _OrderService_UpdateOrderStatus_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "admin/order/v1/order.proto",
}

OrderService_ServiceDesc is the grpc.ServiceDesc for OrderService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterOrderServiceHTTPServer

func RegisterOrderServiceHTTPServer(s *http.Server, srv OrderServiceHTTPServer)

func RegisterOrderServiceServer

func RegisterOrderServiceServer(s grpc.ServiceRegistrar, srv OrderServiceServer)

Types

type CreateOrderReply

type CreateOrderReply struct {
	Code    int32  `protobuf:"varint,1,opt,name=code,proto3" json:"code,omitempty"`      // 状态码
	Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"` // 消息内容
	// contains filtered or unexported fields
}

CreateOrderReply 创建订单响应

func (*CreateOrderReply) Descriptor deprecated

func (*CreateOrderReply) Descriptor() ([]byte, []int)

Deprecated: Use CreateOrderReply.ProtoReflect.Descriptor instead.

func (*CreateOrderReply) GetCode

func (x *CreateOrderReply) GetCode() int32

func (*CreateOrderReply) GetMessage

func (x *CreateOrderReply) GetMessage() string

func (*CreateOrderReply) ProtoMessage

func (*CreateOrderReply) ProtoMessage()

func (*CreateOrderReply) ProtoReflect

func (x *CreateOrderReply) ProtoReflect() protoreflect.Message

func (*CreateOrderReply) Reset

func (x *CreateOrderReply) Reset()

func (*CreateOrderReply) String

func (x *CreateOrderReply) String() string

func (*CreateOrderReply) Validate

func (m *CreateOrderReply) Validate() error

Validate checks the field values on CreateOrderReply with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*CreateOrderReply) ValidateAll

func (m *CreateOrderReply) ValidateAll() error

ValidateAll checks the field values on CreateOrderReply with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in CreateOrderReplyMultiError, or nil if none found.

type CreateOrderReplyMultiError

type CreateOrderReplyMultiError []error

CreateOrderReplyMultiError is an error wrapping multiple validation errors returned by CreateOrderReply.ValidateAll() if the designated constraints aren't met.

func (CreateOrderReplyMultiError) AllErrors

func (m CreateOrderReplyMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (CreateOrderReplyMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type CreateOrderReplyValidationError

type CreateOrderReplyValidationError struct {
	// contains filtered or unexported fields
}

CreateOrderReplyValidationError is the validation error returned by CreateOrderReply.Validate if the designated constraints aren't met.

func (CreateOrderReplyValidationError) Cause

Cause function returns cause value.

func (CreateOrderReplyValidationError) Error

Error satisfies the builtin error interface

func (CreateOrderReplyValidationError) ErrorName

ErrorName returns error name.

func (CreateOrderReplyValidationError) Field

Field function returns field value.

func (CreateOrderReplyValidationError) Key

Key function returns key value.

func (CreateOrderReplyValidationError) Reason

Reason function returns reason value.

type CreateOrderRequest

type CreateOrderRequest struct {
	UserId         int64  `protobuf:"varint,1,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`                         // 用户ID
	Type           uint32 `protobuf:"varint,2,opt,name=type,proto3" json:"type,omitempty"`                                           // 订单类型:1:订阅 2:续费 3:重置流量 4:充值
	Quantity       int64  `protobuf:"varint,3,opt,name=quantity,proto3" json:"quantity,omitempty"`                                   // 数量
	Price          int64  `protobuf:"varint,4,opt,name=price,proto3" json:"price,omitempty"`                                         // 原价(分)
	Amount         int64  `protobuf:"varint,5,opt,name=amount,proto3" json:"amount,omitempty"`                                       // 订单金额(分)
	Discount       int64  `protobuf:"varint,6,opt,name=discount,proto3" json:"discount,omitempty"`                                   // 折扣金额(分)
	Coupon         string `protobuf:"bytes,7,opt,name=coupon,proto3" json:"coupon,omitempty"`                                        // 优惠券
	CouponDiscount int64  `protobuf:"varint,8,opt,name=coupon_discount,json=couponDiscount,proto3" json:"coupon_discount,omitempty"` // 优惠券折扣金额(分)
	Commission     int64  `protobuf:"varint,9,opt,name=commission,proto3" json:"commission,omitempty"`                               // 订单佣金(分)
	FeeAmount      int64  `protobuf:"varint,10,opt,name=fee_amount,json=feeAmount,proto3" json:"fee_amount,omitempty"`               // 手续费金额(分)
	PaymentId      int64  `protobuf:"varint,11,opt,name=payment_id,json=paymentId,proto3" json:"payment_id,omitempty"`               // 支付方式ID
	TradeNo        string `protobuf:"bytes,12,opt,name=trade_no,json=tradeNo,proto3" json:"trade_no,omitempty"`                      // 交易号
	Status         uint32 `protobuf:"varint,13,opt,name=status,proto3" json:"status,omitempty"`                                      // 订单状态:1:待付款 2:已付款 3:关闭 4:失败 5:已完成
	SubscribeId    int64  `protobuf:"varint,14,opt,name=subscribe_id,json=subscribeId,proto3" json:"subscribe_id,omitempty"`         // 订阅ID
	// contains filtered or unexported fields
}

CreateOrderRequest 创建订单请求

func (*CreateOrderRequest) Descriptor deprecated

func (*CreateOrderRequest) Descriptor() ([]byte, []int)

Deprecated: Use CreateOrderRequest.ProtoReflect.Descriptor instead.

func (*CreateOrderRequest) GetAmount

func (x *CreateOrderRequest) GetAmount() int64

func (*CreateOrderRequest) GetCommission

func (x *CreateOrderRequest) GetCommission() int64

func (*CreateOrderRequest) GetCoupon

func (x *CreateOrderRequest) GetCoupon() string

func (*CreateOrderRequest) GetCouponDiscount

func (x *CreateOrderRequest) GetCouponDiscount() int64

func (*CreateOrderRequest) GetDiscount

func (x *CreateOrderRequest) GetDiscount() int64

func (*CreateOrderRequest) GetFeeAmount

func (x *CreateOrderRequest) GetFeeAmount() int64

func (*CreateOrderRequest) GetPaymentId

func (x *CreateOrderRequest) GetPaymentId() int64

func (*CreateOrderRequest) GetPrice

func (x *CreateOrderRequest) GetPrice() int64

func (*CreateOrderRequest) GetQuantity

func (x *CreateOrderRequest) GetQuantity() int64

func (*CreateOrderRequest) GetStatus

func (x *CreateOrderRequest) GetStatus() uint32

func (*CreateOrderRequest) GetSubscribeId

func (x *CreateOrderRequest) GetSubscribeId() int64

func (*CreateOrderRequest) GetTradeNo

func (x *CreateOrderRequest) GetTradeNo() string

func (*CreateOrderRequest) GetType

func (x *CreateOrderRequest) GetType() uint32

func (*CreateOrderRequest) GetUserId

func (x *CreateOrderRequest) GetUserId() int64

func (*CreateOrderRequest) ProtoMessage

func (*CreateOrderRequest) ProtoMessage()

func (*CreateOrderRequest) ProtoReflect

func (x *CreateOrderRequest) ProtoReflect() protoreflect.Message

func (*CreateOrderRequest) Reset

func (x *CreateOrderRequest) Reset()

func (*CreateOrderRequest) String

func (x *CreateOrderRequest) String() string

func (*CreateOrderRequest) Validate

func (m *CreateOrderRequest) Validate() error

Validate checks the field values on CreateOrderRequest with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*CreateOrderRequest) ValidateAll

func (m *CreateOrderRequest) ValidateAll() error

ValidateAll checks the field values on CreateOrderRequest with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in CreateOrderRequestMultiError, or nil if none found.

type CreateOrderRequestMultiError

type CreateOrderRequestMultiError []error

CreateOrderRequestMultiError is an error wrapping multiple validation errors returned by CreateOrderRequest.ValidateAll() if the designated constraints aren't met.

func (CreateOrderRequestMultiError) AllErrors

func (m CreateOrderRequestMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (CreateOrderRequestMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type CreateOrderRequestValidationError

type CreateOrderRequestValidationError struct {
	// contains filtered or unexported fields
}

CreateOrderRequestValidationError is the validation error returned by CreateOrderRequest.Validate if the designated constraints aren't met.

func (CreateOrderRequestValidationError) Cause

Cause function returns cause value.

func (CreateOrderRequestValidationError) Error

Error satisfies the builtin error interface

func (CreateOrderRequestValidationError) ErrorName

ErrorName returns error name.

func (CreateOrderRequestValidationError) Field

Field function returns field value.

func (CreateOrderRequestValidationError) Key

Key function returns key value.

func (CreateOrderRequestValidationError) Reason

Reason function returns reason value.

type GetOrderListData

type GetOrderListData struct {
	Total int32        `protobuf:"varint,1,opt,name=total,proto3" json:"total,omitempty"` // 总数
	List  []*OrderItem `protobuf:"bytes,2,rep,name=list,proto3" json:"list,omitempty"`    // 订单列表
	// contains filtered or unexported fields
}

GetOrderListData 获取订单列表数据

func (*GetOrderListData) Descriptor deprecated

func (*GetOrderListData) Descriptor() ([]byte, []int)

Deprecated: Use GetOrderListData.ProtoReflect.Descriptor instead.

func (*GetOrderListData) GetList

func (x *GetOrderListData) GetList() []*OrderItem

func (*GetOrderListData) GetTotal

func (x *GetOrderListData) GetTotal() int32

func (*GetOrderListData) ProtoMessage

func (*GetOrderListData) ProtoMessage()

func (*GetOrderListData) ProtoReflect

func (x *GetOrderListData) ProtoReflect() protoreflect.Message

func (*GetOrderListData) Reset

func (x *GetOrderListData) Reset()

func (*GetOrderListData) String

func (x *GetOrderListData) String() string

func (*GetOrderListData) Validate

func (m *GetOrderListData) Validate() error

Validate checks the field values on GetOrderListData with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*GetOrderListData) ValidateAll

func (m *GetOrderListData) ValidateAll() error

ValidateAll checks the field values on GetOrderListData with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in GetOrderListDataMultiError, or nil if none found.

type GetOrderListDataMultiError

type GetOrderListDataMultiError []error

GetOrderListDataMultiError is an error wrapping multiple validation errors returned by GetOrderListData.ValidateAll() if the designated constraints aren't met.

func (GetOrderListDataMultiError) AllErrors

func (m GetOrderListDataMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (GetOrderListDataMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type GetOrderListDataValidationError

type GetOrderListDataValidationError struct {
	// contains filtered or unexported fields
}

GetOrderListDataValidationError is the validation error returned by GetOrderListData.Validate if the designated constraints aren't met.

func (GetOrderListDataValidationError) Cause

Cause function returns cause value.

func (GetOrderListDataValidationError) Error

Error satisfies the builtin error interface

func (GetOrderListDataValidationError) ErrorName

ErrorName returns error name.

func (GetOrderListDataValidationError) Field

Field function returns field value.

func (GetOrderListDataValidationError) Key

Key function returns key value.

func (GetOrderListDataValidationError) Reason

Reason function returns reason value.

type GetOrderListReply

type GetOrderListReply struct {
	Code    int32             `protobuf:"varint,1,opt,name=code,proto3" json:"code,omitempty"`      // 状态码
	Message string            `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"` // 消息内容
	Data    *GetOrderListData `protobuf:"bytes,3,opt,name=data,proto3" json:"data,omitempty"`       // 响应数据
	// contains filtered or unexported fields
}

GetOrderListReply 获取订单列表响应

func (*GetOrderListReply) Descriptor deprecated

func (*GetOrderListReply) Descriptor() ([]byte, []int)

Deprecated: Use GetOrderListReply.ProtoReflect.Descriptor instead.

func (*GetOrderListReply) GetCode

func (x *GetOrderListReply) GetCode() int32

func (*GetOrderListReply) GetData

func (x *GetOrderListReply) GetData() *GetOrderListData

func (*GetOrderListReply) GetMessage

func (x *GetOrderListReply) GetMessage() string

func (*GetOrderListReply) ProtoMessage

func (*GetOrderListReply) ProtoMessage()

func (*GetOrderListReply) ProtoReflect

func (x *GetOrderListReply) ProtoReflect() protoreflect.Message

func (*GetOrderListReply) Reset

func (x *GetOrderListReply) Reset()

func (*GetOrderListReply) String

func (x *GetOrderListReply) String() string

func (*GetOrderListReply) Validate

func (m *GetOrderListReply) Validate() error

Validate checks the field values on GetOrderListReply with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*GetOrderListReply) ValidateAll

func (m *GetOrderListReply) ValidateAll() error

ValidateAll checks the field values on GetOrderListReply with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in GetOrderListReplyMultiError, or nil if none found.

type GetOrderListReplyMultiError

type GetOrderListReplyMultiError []error

GetOrderListReplyMultiError is an error wrapping multiple validation errors returned by GetOrderListReply.ValidateAll() if the designated constraints aren't met.

func (GetOrderListReplyMultiError) AllErrors

func (m GetOrderListReplyMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (GetOrderListReplyMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type GetOrderListReplyValidationError

type GetOrderListReplyValidationError struct {
	// contains filtered or unexported fields
}

GetOrderListReplyValidationError is the validation error returned by GetOrderListReply.Validate if the designated constraints aren't met.

func (GetOrderListReplyValidationError) Cause

Cause function returns cause value.

func (GetOrderListReplyValidationError) Error

Error satisfies the builtin error interface

func (GetOrderListReplyValidationError) ErrorName

ErrorName returns error name.

func (GetOrderListReplyValidationError) Field

Field function returns field value.

func (GetOrderListReplyValidationError) Key

Key function returns key value.

func (GetOrderListReplyValidationError) Reason

Reason function returns reason value.

type GetOrderListRequest

type GetOrderListRequest struct {
	Page        int64  `protobuf:"varint,1,opt,name=page,proto3" json:"page,omitempty"`                                  // 页码
	Size        int64  `protobuf:"varint,2,opt,name=size,proto3" json:"size,omitempty"`                                  // 每页数量
	UserId      int64  `protobuf:"varint,3,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`                // 用户ID(可选)
	Status      uint32 `protobuf:"varint,4,opt,name=status,proto3" json:"status,omitempty"`                              // 订单状态(可选)
	SubscribeId int64  `protobuf:"varint,5,opt,name=subscribe_id,json=subscribeId,proto3" json:"subscribe_id,omitempty"` // 订阅ID(可选)
	Search      string `protobuf:"bytes,6,opt,name=search,proto3" json:"search,omitempty"`                               // 搜索关键字
	// contains filtered or unexported fields
}

GetOrderListRequest 获取订单列表请求

func (*GetOrderListRequest) Descriptor deprecated

func (*GetOrderListRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetOrderListRequest.ProtoReflect.Descriptor instead.

func (*GetOrderListRequest) GetPage

func (x *GetOrderListRequest) GetPage() int64

func (*GetOrderListRequest) GetSearch

func (x *GetOrderListRequest) GetSearch() string

func (*GetOrderListRequest) GetSize

func (x *GetOrderListRequest) GetSize() int64

func (*GetOrderListRequest) GetStatus

func (x *GetOrderListRequest) GetStatus() uint32

func (*GetOrderListRequest) GetSubscribeId

func (x *GetOrderListRequest) GetSubscribeId() int64

func (*GetOrderListRequest) GetUserId

func (x *GetOrderListRequest) GetUserId() int64

func (*GetOrderListRequest) ProtoMessage

func (*GetOrderListRequest) ProtoMessage()

func (*GetOrderListRequest) ProtoReflect

func (x *GetOrderListRequest) ProtoReflect() protoreflect.Message

func (*GetOrderListRequest) Reset

func (x *GetOrderListRequest) Reset()

func (*GetOrderListRequest) String

func (x *GetOrderListRequest) String() string

func (*GetOrderListRequest) Validate

func (m *GetOrderListRequest) Validate() error

Validate checks the field values on GetOrderListRequest with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*GetOrderListRequest) ValidateAll

func (m *GetOrderListRequest) ValidateAll() error

ValidateAll checks the field values on GetOrderListRequest with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in GetOrderListRequestMultiError, or nil if none found.

type GetOrderListRequestMultiError

type GetOrderListRequestMultiError []error

GetOrderListRequestMultiError is an error wrapping multiple validation errors returned by GetOrderListRequest.ValidateAll() if the designated constraints aren't met.

func (GetOrderListRequestMultiError) AllErrors

func (m GetOrderListRequestMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (GetOrderListRequestMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type GetOrderListRequestValidationError

type GetOrderListRequestValidationError struct {
	// contains filtered or unexported fields
}

GetOrderListRequestValidationError is the validation error returned by GetOrderListRequest.Validate if the designated constraints aren't met.

func (GetOrderListRequestValidationError) Cause

Cause function returns cause value.

func (GetOrderListRequestValidationError) Error

Error satisfies the builtin error interface

func (GetOrderListRequestValidationError) ErrorName

ErrorName returns error name.

func (GetOrderListRequestValidationError) Field

Field function returns field value.

func (GetOrderListRequestValidationError) Key

Key function returns key value.

func (GetOrderListRequestValidationError) Reason

Reason function returns reason value.

type OrderItem

type OrderItem struct {
	Id             int64  `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`                                                // 订单ID
	ParentId       int64  `protobuf:"varint,2,opt,name=parent_id,json=parentId,proto3" json:"parent_id,omitempty"`                    // 父订单ID
	UserId         int64  `protobuf:"varint,3,opt,name=user_id,json=userId,proto3" json:"user_id,omitempty"`                          // 用户ID
	OrderNo        string `protobuf:"bytes,4,opt,name=order_no,json=orderNo,proto3" json:"order_no,omitempty"`                        // 订单号
	Type           uint32 `protobuf:"varint,5,opt,name=type,proto3" json:"type,omitempty"`                                            // 订单类型
	Quantity       int64  `protobuf:"varint,6,opt,name=quantity,proto3" json:"quantity,omitempty"`                                    // 数量
	Price          int64  `protobuf:"varint,7,opt,name=price,proto3" json:"price,omitempty"`                                          // 原价(分)
	Amount         int64  `protobuf:"varint,8,opt,name=amount,proto3" json:"amount,omitempty"`                                        // 订单金额(分)
	GiftAmount     int64  `protobuf:"varint,9,opt,name=gift_amount,json=giftAmount,proto3" json:"gift_amount,omitempty"`              // 礼品金额(分)
	Discount       int64  `protobuf:"varint,10,opt,name=discount,proto3" json:"discount,omitempty"`                                   // 折扣金额(分)
	Coupon         string `protobuf:"bytes,11,opt,name=coupon,proto3" json:"coupon,omitempty"`                                        // 优惠券
	CouponDiscount int64  `protobuf:"varint,12,opt,name=coupon_discount,json=couponDiscount,proto3" json:"coupon_discount,omitempty"` // 优惠券折扣金额(分)
	Commission     int64  `protobuf:"varint,13,opt,name=commission,proto3" json:"commission,omitempty"`                               // 订单佣金(分)
	PaymentId      int64  `protobuf:"varint,14,opt,name=payment_id,json=paymentId,proto3" json:"payment_id,omitempty"`                // 支付方式ID
	Method         string `protobuf:"bytes,15,opt,name=method,proto3" json:"method,omitempty"`                                        // 支付方式名称
	FeeAmount      int64  `protobuf:"varint,16,opt,name=fee_amount,json=feeAmount,proto3" json:"fee_amount,omitempty"`                // 手续费金额(分)
	TradeNo        string `protobuf:"bytes,17,opt,name=trade_no,json=tradeNo,proto3" json:"trade_no,omitempty"`                       // 交易号
	Status         uint32 `protobuf:"varint,18,opt,name=status,proto3" json:"status,omitempty"`                                       // 订单状态
	SubscribeId    int64  `protobuf:"varint,19,opt,name=subscribe_id,json=subscribeId,proto3" json:"subscribe_id,omitempty"`          // 订阅ID
	SubscribeToken string `protobuf:"bytes,20,opt,name=subscribe_token,json=subscribeToken,proto3" json:"subscribe_token,omitempty"`  // 续费订阅令牌
	IsNew          bool   `protobuf:"varint,21,opt,name=is_new,json=isNew,proto3" json:"is_new,omitempty"`                            // 是否新订单
	CreatedAt      int64  `protobuf:"varint,22,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`                // 创建时间(Unix时间戳,毫秒)
	UpdatedAt      int64  `protobuf:"varint,23,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`                // 更新时间(Unix时间戳,毫秒)
	// contains filtered or unexported fields
}

OrderItem 订单项

func (*OrderItem) Descriptor deprecated

func (*OrderItem) Descriptor() ([]byte, []int)

Deprecated: Use OrderItem.ProtoReflect.Descriptor instead.

func (*OrderItem) GetAmount

func (x *OrderItem) GetAmount() int64

func (*OrderItem) GetCommission

func (x *OrderItem) GetCommission() int64

func (*OrderItem) GetCoupon

func (x *OrderItem) GetCoupon() string

func (*OrderItem) GetCouponDiscount

func (x *OrderItem) GetCouponDiscount() int64

func (*OrderItem) GetCreatedAt

func (x *OrderItem) GetCreatedAt() int64

func (*OrderItem) GetDiscount

func (x *OrderItem) GetDiscount() int64

func (*OrderItem) GetFeeAmount

func (x *OrderItem) GetFeeAmount() int64

func (*OrderItem) GetGiftAmount

func (x *OrderItem) GetGiftAmount() int64

func (*OrderItem) GetId

func (x *OrderItem) GetId() int64

func (*OrderItem) GetIsNew

func (x *OrderItem) GetIsNew() bool

func (*OrderItem) GetMethod

func (x *OrderItem) GetMethod() string

func (*OrderItem) GetOrderNo

func (x *OrderItem) GetOrderNo() string

func (*OrderItem) GetParentId

func (x *OrderItem) GetParentId() int64

func (*OrderItem) GetPaymentId

func (x *OrderItem) GetPaymentId() int64

func (*OrderItem) GetPrice

func (x *OrderItem) GetPrice() int64

func (*OrderItem) GetQuantity

func (x *OrderItem) GetQuantity() int64

func (*OrderItem) GetStatus

func (x *OrderItem) GetStatus() uint32

func (*OrderItem) GetSubscribeId

func (x *OrderItem) GetSubscribeId() int64

func (*OrderItem) GetSubscribeToken

func (x *OrderItem) GetSubscribeToken() string

func (*OrderItem) GetTradeNo

func (x *OrderItem) GetTradeNo() string

func (*OrderItem) GetType

func (x *OrderItem) GetType() uint32

func (*OrderItem) GetUpdatedAt

func (x *OrderItem) GetUpdatedAt() int64

func (*OrderItem) GetUserId

func (x *OrderItem) GetUserId() int64

func (*OrderItem) ProtoMessage

func (*OrderItem) ProtoMessage()

func (*OrderItem) ProtoReflect

func (x *OrderItem) ProtoReflect() protoreflect.Message

func (*OrderItem) Reset

func (x *OrderItem) Reset()

func (*OrderItem) String

func (x *OrderItem) String() string

func (*OrderItem) Validate

func (m *OrderItem) Validate() error

Validate checks the field values on OrderItem with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*OrderItem) ValidateAll

func (m *OrderItem) ValidateAll() error

ValidateAll checks the field values on OrderItem with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in OrderItemMultiError, or nil if none found.

type OrderItemMultiError

type OrderItemMultiError []error

OrderItemMultiError is an error wrapping multiple validation errors returned by OrderItem.ValidateAll() if the designated constraints aren't met.

func (OrderItemMultiError) AllErrors

func (m OrderItemMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (OrderItemMultiError) Error

func (m OrderItemMultiError) Error() string

Error returns a concatenation of all the error messages it wraps.

type OrderItemValidationError

type OrderItemValidationError struct {
	// contains filtered or unexported fields
}

OrderItemValidationError is the validation error returned by OrderItem.Validate if the designated constraints aren't met.

func (OrderItemValidationError) Cause

func (e OrderItemValidationError) Cause() error

Cause function returns cause value.

func (OrderItemValidationError) Error

func (e OrderItemValidationError) Error() string

Error satisfies the builtin error interface

func (OrderItemValidationError) ErrorName

func (e OrderItemValidationError) ErrorName() string

ErrorName returns error name.

func (OrderItemValidationError) Field

func (e OrderItemValidationError) Field() string

Field function returns field value.

func (OrderItemValidationError) Key

Key function returns key value.

func (OrderItemValidationError) Reason

func (e OrderItemValidationError) Reason() string

Reason function returns reason value.

type OrderServiceClient

type OrderServiceClient interface {
	// CreateOrder 创建订单
	CreateOrder(ctx context.Context, in *CreateOrderRequest, opts ...grpc.CallOption) (*CreateOrderReply, error)
	// GetOrderList 获取订单列表
	GetOrderList(ctx context.Context, in *GetOrderListRequest, opts ...grpc.CallOption) (*GetOrderListReply, error)
	// UpdateOrderStatus 更新订单状态
	UpdateOrderStatus(ctx context.Context, in *UpdateOrderStatusRequest, opts ...grpc.CallOption) (*UpdateOrderStatusReply, error)
}

OrderServiceClient is the client API for OrderService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type OrderServiceHTTPClient

type OrderServiceHTTPClient interface {
	// CreateOrder CreateOrder 创建订单
	CreateOrder(ctx context.Context, req *CreateOrderRequest, opts ...http.CallOption) (rsp *CreateOrderReply, err error)
	// GetOrderList GetOrderList 获取订单列表
	GetOrderList(ctx context.Context, req *GetOrderListRequest, opts ...http.CallOption) (rsp *GetOrderListReply, err error)
	// UpdateOrderStatus UpdateOrderStatus 更新订单状态
	UpdateOrderStatus(ctx context.Context, req *UpdateOrderStatusRequest, opts ...http.CallOption) (rsp *UpdateOrderStatusReply, err error)
}

func NewOrderServiceHTTPClient

func NewOrderServiceHTTPClient(client *http.Client) OrderServiceHTTPClient

type OrderServiceHTTPClientImpl

type OrderServiceHTTPClientImpl struct {
	// contains filtered or unexported fields
}

func (*OrderServiceHTTPClientImpl) CreateOrder

CreateOrder CreateOrder 创建订单

func (*OrderServiceHTTPClientImpl) GetOrderList

GetOrderList GetOrderList 获取订单列表

func (*OrderServiceHTTPClientImpl) UpdateOrderStatus

UpdateOrderStatus UpdateOrderStatus 更新订单状态

type OrderServiceHTTPServer

type OrderServiceHTTPServer interface {
	// CreateOrder CreateOrder 创建订单
	CreateOrder(context.Context, *CreateOrderRequest) (*CreateOrderReply, error)
	// GetOrderList GetOrderList 获取订单列表
	GetOrderList(context.Context, *GetOrderListRequest) (*GetOrderListReply, error)
	// UpdateOrderStatus UpdateOrderStatus 更新订单状态
	UpdateOrderStatus(context.Context, *UpdateOrderStatusRequest) (*UpdateOrderStatusReply, error)
}

type OrderServiceServer

type OrderServiceServer interface {
	// CreateOrder 创建订单
	CreateOrder(context.Context, *CreateOrderRequest) (*CreateOrderReply, error)
	// GetOrderList 获取订单列表
	GetOrderList(context.Context, *GetOrderListRequest) (*GetOrderListReply, error)
	// UpdateOrderStatus 更新订单状态
	UpdateOrderStatus(context.Context, *UpdateOrderStatusRequest) (*UpdateOrderStatusReply, error)
	// contains filtered or unexported methods
}

OrderServiceServer is the server API for OrderService service. All implementations must embed UnimplementedOrderServiceServer for forward compatibility.

type UnimplementedOrderServiceServer

type UnimplementedOrderServiceServer struct{}

UnimplementedOrderServiceServer must be embedded to have forward compatible implementations.

NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.

func (UnimplementedOrderServiceServer) CreateOrder

func (UnimplementedOrderServiceServer) GetOrderList

func (UnimplementedOrderServiceServer) UpdateOrderStatus

type UnsafeOrderServiceServer

type UnsafeOrderServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeOrderServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to OrderServiceServer will result in compilation errors.

type UpdateOrderStatusReply

type UpdateOrderStatusReply struct {
	Code    int32  `protobuf:"varint,1,opt,name=code,proto3" json:"code,omitempty"`      // 状态码
	Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"` // 消息内容
	// contains filtered or unexported fields
}

UpdateOrderStatusReply 更新订单状态响应

func (*UpdateOrderStatusReply) Descriptor deprecated

func (*UpdateOrderStatusReply) Descriptor() ([]byte, []int)

Deprecated: Use UpdateOrderStatusReply.ProtoReflect.Descriptor instead.

func (*UpdateOrderStatusReply) GetCode

func (x *UpdateOrderStatusReply) GetCode() int32

func (*UpdateOrderStatusReply) GetMessage

func (x *UpdateOrderStatusReply) GetMessage() string

func (*UpdateOrderStatusReply) ProtoMessage

func (*UpdateOrderStatusReply) ProtoMessage()

func (*UpdateOrderStatusReply) ProtoReflect

func (x *UpdateOrderStatusReply) ProtoReflect() protoreflect.Message

func (*UpdateOrderStatusReply) Reset

func (x *UpdateOrderStatusReply) Reset()

func (*UpdateOrderStatusReply) String

func (x *UpdateOrderStatusReply) String() string

func (*UpdateOrderStatusReply) Validate

func (m *UpdateOrderStatusReply) Validate() error

Validate checks the field values on UpdateOrderStatusReply with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*UpdateOrderStatusReply) ValidateAll

func (m *UpdateOrderStatusReply) ValidateAll() error

ValidateAll checks the field values on UpdateOrderStatusReply with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in UpdateOrderStatusReplyMultiError, or nil if none found.

type UpdateOrderStatusReplyMultiError

type UpdateOrderStatusReplyMultiError []error

UpdateOrderStatusReplyMultiError is an error wrapping multiple validation errors returned by UpdateOrderStatusReply.ValidateAll() if the designated constraints aren't met.

func (UpdateOrderStatusReplyMultiError) AllErrors

func (m UpdateOrderStatusReplyMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (UpdateOrderStatusReplyMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type UpdateOrderStatusReplyValidationError

type UpdateOrderStatusReplyValidationError struct {
	// contains filtered or unexported fields
}

UpdateOrderStatusReplyValidationError is the validation error returned by UpdateOrderStatusReply.Validate if the designated constraints aren't met.

func (UpdateOrderStatusReplyValidationError) Cause

Cause function returns cause value.

func (UpdateOrderStatusReplyValidationError) Error

Error satisfies the builtin error interface

func (UpdateOrderStatusReplyValidationError) ErrorName

ErrorName returns error name.

func (UpdateOrderStatusReplyValidationError) Field

Field function returns field value.

func (UpdateOrderStatusReplyValidationError) Key

Key function returns key value.

func (UpdateOrderStatusReplyValidationError) Reason

Reason function returns reason value.

type UpdateOrderStatusRequest

type UpdateOrderStatusRequest struct {
	Id        int64  `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`                                // 订单ID
	Status    uint32 `protobuf:"varint,2,opt,name=status,proto3" json:"status,omitempty"`                        // 订单状态
	PaymentId int64  `protobuf:"varint,3,opt,name=payment_id,json=paymentId,proto3" json:"payment_id,omitempty"` // 支付方式ID(可选)
	TradeNo   string `protobuf:"bytes,4,opt,name=trade_no,json=tradeNo,proto3" json:"trade_no,omitempty"`        // 交易号(可选)
	// contains filtered or unexported fields
}

UpdateOrderStatusRequest 更新订单状态请求

func (*UpdateOrderStatusRequest) Descriptor deprecated

func (*UpdateOrderStatusRequest) Descriptor() ([]byte, []int)

Deprecated: Use UpdateOrderStatusRequest.ProtoReflect.Descriptor instead.

func (*UpdateOrderStatusRequest) GetId

func (x *UpdateOrderStatusRequest) GetId() int64

func (*UpdateOrderStatusRequest) GetPaymentId

func (x *UpdateOrderStatusRequest) GetPaymentId() int64

func (*UpdateOrderStatusRequest) GetStatus

func (x *UpdateOrderStatusRequest) GetStatus() uint32

func (*UpdateOrderStatusRequest) GetTradeNo

func (x *UpdateOrderStatusRequest) GetTradeNo() string

func (*UpdateOrderStatusRequest) ProtoMessage

func (*UpdateOrderStatusRequest) ProtoMessage()

func (*UpdateOrderStatusRequest) ProtoReflect

func (x *UpdateOrderStatusRequest) ProtoReflect() protoreflect.Message

func (*UpdateOrderStatusRequest) Reset

func (x *UpdateOrderStatusRequest) Reset()

func (*UpdateOrderStatusRequest) String

func (x *UpdateOrderStatusRequest) String() string

func (*UpdateOrderStatusRequest) Validate

func (m *UpdateOrderStatusRequest) Validate() error

Validate checks the field values on UpdateOrderStatusRequest with the rules defined in the proto definition for this message. If any rules are violated, the first error encountered is returned, or nil if there are no violations.

func (*UpdateOrderStatusRequest) ValidateAll

func (m *UpdateOrderStatusRequest) ValidateAll() error

ValidateAll checks the field values on UpdateOrderStatusRequest with the rules defined in the proto definition for this message. If any rules are violated, the result is a list of violation errors wrapped in UpdateOrderStatusRequestMultiError, or nil if none found.

type UpdateOrderStatusRequestMultiError

type UpdateOrderStatusRequestMultiError []error

UpdateOrderStatusRequestMultiError is an error wrapping multiple validation errors returned by UpdateOrderStatusRequest.ValidateAll() if the designated constraints aren't met.

func (UpdateOrderStatusRequestMultiError) AllErrors

func (m UpdateOrderStatusRequestMultiError) AllErrors() []error

AllErrors returns a list of validation violation errors.

func (UpdateOrderStatusRequestMultiError) Error

Error returns a concatenation of all the error messages it wraps.

type UpdateOrderStatusRequestValidationError

type UpdateOrderStatusRequestValidationError struct {
	// contains filtered or unexported fields
}

UpdateOrderStatusRequestValidationError is the validation error returned by UpdateOrderStatusRequest.Validate if the designated constraints aren't met.

func (UpdateOrderStatusRequestValidationError) Cause

Cause function returns cause value.

func (UpdateOrderStatusRequestValidationError) Error

Error satisfies the builtin error interface

func (UpdateOrderStatusRequestValidationError) ErrorName

ErrorName returns error name.

func (UpdateOrderStatusRequestValidationError) Field

Field function returns field value.

func (UpdateOrderStatusRequestValidationError) Key

Key function returns key value.

func (UpdateOrderStatusRequestValidationError) Reason

Reason function returns reason value.

Jump to