proxyredemptionrecord

package
v1.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 23, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the proxyredemptionrecord type in the database.
	Label = "proxy_redemption_record"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldRedemptionCodeID holds the string denoting the redemption_code_id field in the database.
	FieldRedemptionCodeID = "redemption_code_id"
	// FieldUserID holds the string denoting the user_id field in the database.
	FieldUserID = "user_id"
	// FieldSubscribeID holds the string denoting the subscribe_id field in the database.
	FieldSubscribeID = "subscribe_id"
	// FieldUnitTime holds the string denoting the unit_time field in the database.
	FieldUnitTime = "unit_time"
	// FieldQuantity holds the string denoting the quantity field in the database.
	FieldQuantity = "quantity"
	// FieldRedeemedAt holds the string denoting the redeemed_at field in the database.
	FieldRedeemedAt = "redeemed_at"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// EdgeUser holds the string denoting the user edge name in mutations.
	EdgeUser = "user"
	// EdgeRedemptionCode holds the string denoting the redemption_code edge name in mutations.
	EdgeRedemptionCode = "redemption_code"
	// Table holds the table name of the proxyredemptionrecord in the database.
	Table = "redemption_record"
	// UserTable is the table that holds the user relation/edge.
	UserTable = "redemption_record"
	// UserInverseTable is the table name for the ProxyUser entity.
	// It exists in this package in order to avoid circular dependency with the "proxyuser" package.
	UserInverseTable = "user"
	// UserColumn is the table column denoting the user relation/edge.
	UserColumn = "user_id"
	// RedemptionCodeTable is the table that holds the redemption_code relation/edge.
	RedemptionCodeTable = "redemption_record"
	// RedemptionCodeInverseTable is the table name for the ProxyRedemptionCode entity.
	// It exists in this package in order to avoid circular dependency with the "proxyredemptioncode" package.
	RedemptionCodeInverseTable = "redemption_code"
	// RedemptionCodeColumn is the table column denoting the redemption_code relation/edge.
	RedemptionCodeColumn = "redemption_code_id"
)

Variables

var (
	// DefaultUnitTime holds the default value on creation for the "unit_time" field.
	DefaultUnitTime string
	// UnitTimeValidator is a validator for the "unit_time" field. It is called by the builders before save.
	UnitTimeValidator func(string) error
	// DefaultQuantity holds the default value on creation for the "quantity" field.
	DefaultQuantity int32
	// DefaultRedeemedAt holds the default value on creation for the "redeemed_at" field.
	DefaultRedeemedAt func() time.Time
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// IDValidator is a validator for the "id" field. It is called by the builders before save.
	IDValidator func(int64) error
)

Columns holds all SQL columns for proxyredemptionrecord fields.

Functions

func And

And groups predicates with the AND operator between them.

func CreatedAt

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.ProxyRedemptionRecord

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.ProxyRedemptionRecord

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtLT

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.ProxyRedemptionRecord

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.ProxyRedemptionRecord

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.ProxyRedemptionRecord

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func HasRedemptionCode

func HasRedemptionCode() predicate.ProxyRedemptionRecord

HasRedemptionCode applies the HasEdge predicate on the "redemption_code" edge.

func HasRedemptionCodeWith

func HasRedemptionCodeWith(preds ...predicate.ProxyRedemptionCode) predicate.ProxyRedemptionRecord

HasRedemptionCodeWith applies the HasEdge predicate on the "redemption_code" edge with a given conditions (other predicates).

func HasUser

HasUser applies the HasEdge predicate on the "user" edge.

func HasUserWith

func HasUserWith(preds ...predicate.ProxyUser) predicate.ProxyRedemptionRecord

HasUserWith applies the HasEdge predicate on the "user" edge with a given conditions (other predicates).

func ID

ID filters vertices based on their ID field.

func IDEQ

IDEQ applies the EQ predicate on the ID field.

func IDGT

IDGT applies the GT predicate on the ID field.

func IDGTE

IDGTE applies the GTE predicate on the ID field.

func IDIn

IDIn applies the In predicate on the ID field.

func IDLT

IDLT applies the LT predicate on the ID field.

func IDLTE

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int64) predicate.ProxyRedemptionRecord

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

Or groups predicates with the OR operator between them.

func Quantity

Quantity applies equality check predicate on the "quantity" field. It's identical to QuantityEQ.

func QuantityEQ

QuantityEQ applies the EQ predicate on the "quantity" field.

func QuantityGT

QuantityGT applies the GT predicate on the "quantity" field.

func QuantityGTE

func QuantityGTE(v int32) predicate.ProxyRedemptionRecord

QuantityGTE applies the GTE predicate on the "quantity" field.

func QuantityIn

func QuantityIn(vs ...int32) predicate.ProxyRedemptionRecord

QuantityIn applies the In predicate on the "quantity" field.

func QuantityLT

QuantityLT applies the LT predicate on the "quantity" field.

func QuantityLTE

func QuantityLTE(v int32) predicate.ProxyRedemptionRecord

QuantityLTE applies the LTE predicate on the "quantity" field.

func QuantityNEQ

func QuantityNEQ(v int32) predicate.ProxyRedemptionRecord

QuantityNEQ applies the NEQ predicate on the "quantity" field.

func QuantityNotIn

func QuantityNotIn(vs ...int32) predicate.ProxyRedemptionRecord

QuantityNotIn applies the NotIn predicate on the "quantity" field.

func RedeemedAt

RedeemedAt applies equality check predicate on the "redeemed_at" field. It's identical to RedeemedAtEQ.

func RedeemedAtEQ

func RedeemedAtEQ(v time.Time) predicate.ProxyRedemptionRecord

RedeemedAtEQ applies the EQ predicate on the "redeemed_at" field.

func RedeemedAtGT

func RedeemedAtGT(v time.Time) predicate.ProxyRedemptionRecord

RedeemedAtGT applies the GT predicate on the "redeemed_at" field.

func RedeemedAtGTE

func RedeemedAtGTE(v time.Time) predicate.ProxyRedemptionRecord

RedeemedAtGTE applies the GTE predicate on the "redeemed_at" field.

func RedeemedAtIn

func RedeemedAtIn(vs ...time.Time) predicate.ProxyRedemptionRecord

RedeemedAtIn applies the In predicate on the "redeemed_at" field.

func RedeemedAtLT

func RedeemedAtLT(v time.Time) predicate.ProxyRedemptionRecord

RedeemedAtLT applies the LT predicate on the "redeemed_at" field.

func RedeemedAtLTE

func RedeemedAtLTE(v time.Time) predicate.ProxyRedemptionRecord

RedeemedAtLTE applies the LTE predicate on the "redeemed_at" field.

func RedeemedAtNEQ

func RedeemedAtNEQ(v time.Time) predicate.ProxyRedemptionRecord

RedeemedAtNEQ applies the NEQ predicate on the "redeemed_at" field.

func RedeemedAtNotIn

func RedeemedAtNotIn(vs ...time.Time) predicate.ProxyRedemptionRecord

RedeemedAtNotIn applies the NotIn predicate on the "redeemed_at" field.

func RedemptionCodeID

func RedemptionCodeID(v int64) predicate.ProxyRedemptionRecord

RedemptionCodeID applies equality check predicate on the "redemption_code_id" field. It's identical to RedemptionCodeIDEQ.

func RedemptionCodeIDEQ

func RedemptionCodeIDEQ(v int64) predicate.ProxyRedemptionRecord

RedemptionCodeIDEQ applies the EQ predicate on the "redemption_code_id" field.

func RedemptionCodeIDIn

func RedemptionCodeIDIn(vs ...int64) predicate.ProxyRedemptionRecord

RedemptionCodeIDIn applies the In predicate on the "redemption_code_id" field.

func RedemptionCodeIDNEQ

func RedemptionCodeIDNEQ(v int64) predicate.ProxyRedemptionRecord

RedemptionCodeIDNEQ applies the NEQ predicate on the "redemption_code_id" field.

func RedemptionCodeIDNotIn

func RedemptionCodeIDNotIn(vs ...int64) predicate.ProxyRedemptionRecord

RedemptionCodeIDNotIn applies the NotIn predicate on the "redemption_code_id" field.

func SubscribeID

func SubscribeID(v int64) predicate.ProxyRedemptionRecord

SubscribeID applies equality check predicate on the "subscribe_id" field. It's identical to SubscribeIDEQ.

func SubscribeIDEQ

func SubscribeIDEQ(v int64) predicate.ProxyRedemptionRecord

SubscribeIDEQ applies the EQ predicate on the "subscribe_id" field.

func SubscribeIDGT

func SubscribeIDGT(v int64) predicate.ProxyRedemptionRecord

SubscribeIDGT applies the GT predicate on the "subscribe_id" field.

func SubscribeIDGTE

func SubscribeIDGTE(v int64) predicate.ProxyRedemptionRecord

SubscribeIDGTE applies the GTE predicate on the "subscribe_id" field.

func SubscribeIDIn

func SubscribeIDIn(vs ...int64) predicate.ProxyRedemptionRecord

SubscribeIDIn applies the In predicate on the "subscribe_id" field.

func SubscribeIDLT

func SubscribeIDLT(v int64) predicate.ProxyRedemptionRecord

SubscribeIDLT applies the LT predicate on the "subscribe_id" field.

func SubscribeIDLTE

func SubscribeIDLTE(v int64) predicate.ProxyRedemptionRecord

SubscribeIDLTE applies the LTE predicate on the "subscribe_id" field.

func SubscribeIDNEQ

func SubscribeIDNEQ(v int64) predicate.ProxyRedemptionRecord

SubscribeIDNEQ applies the NEQ predicate on the "subscribe_id" field.

func SubscribeIDNotIn

func SubscribeIDNotIn(vs ...int64) predicate.ProxyRedemptionRecord

SubscribeIDNotIn applies the NotIn predicate on the "subscribe_id" field.

func UnitTime

UnitTime applies equality check predicate on the "unit_time" field. It's identical to UnitTimeEQ.

func UnitTimeContains

func UnitTimeContains(v string) predicate.ProxyRedemptionRecord

UnitTimeContains applies the Contains predicate on the "unit_time" field.

func UnitTimeContainsFold

func UnitTimeContainsFold(v string) predicate.ProxyRedemptionRecord

UnitTimeContainsFold applies the ContainsFold predicate on the "unit_time" field.

func UnitTimeEQ

UnitTimeEQ applies the EQ predicate on the "unit_time" field.

func UnitTimeEqualFold

func UnitTimeEqualFold(v string) predicate.ProxyRedemptionRecord

UnitTimeEqualFold applies the EqualFold predicate on the "unit_time" field.

func UnitTimeGT

UnitTimeGT applies the GT predicate on the "unit_time" field.

func UnitTimeGTE

func UnitTimeGTE(v string) predicate.ProxyRedemptionRecord

UnitTimeGTE applies the GTE predicate on the "unit_time" field.

func UnitTimeHasPrefix

func UnitTimeHasPrefix(v string) predicate.ProxyRedemptionRecord

UnitTimeHasPrefix applies the HasPrefix predicate on the "unit_time" field.

func UnitTimeHasSuffix

func UnitTimeHasSuffix(v string) predicate.ProxyRedemptionRecord

UnitTimeHasSuffix applies the HasSuffix predicate on the "unit_time" field.

func UnitTimeIn

func UnitTimeIn(vs ...string) predicate.ProxyRedemptionRecord

UnitTimeIn applies the In predicate on the "unit_time" field.

func UnitTimeLT

UnitTimeLT applies the LT predicate on the "unit_time" field.

func UnitTimeLTE

func UnitTimeLTE(v string) predicate.ProxyRedemptionRecord

UnitTimeLTE applies the LTE predicate on the "unit_time" field.

func UnitTimeNEQ

func UnitTimeNEQ(v string) predicate.ProxyRedemptionRecord

UnitTimeNEQ applies the NEQ predicate on the "unit_time" field.

func UnitTimeNotIn

func UnitTimeNotIn(vs ...string) predicate.ProxyRedemptionRecord

UnitTimeNotIn applies the NotIn predicate on the "unit_time" field.

func UserID

UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.

func UserIDEQ

UserIDEQ applies the EQ predicate on the "user_id" field.

func UserIDIn

func UserIDIn(vs ...int64) predicate.ProxyRedemptionRecord

UserIDIn applies the In predicate on the "user_id" field.

func UserIDNEQ

UserIDNEQ applies the NEQ predicate on the "user_id" field.

func UserIDNotIn

func UserIDNotIn(vs ...int64) predicate.ProxyRedemptionRecord

UserIDNotIn applies the NotIn predicate on the "user_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the ProxyRedemptionRecord queries.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByQuantity

func ByQuantity(opts ...sql.OrderTermOption) OrderOption

ByQuantity orders the results by the quantity field.

func ByRedeemedAt

func ByRedeemedAt(opts ...sql.OrderTermOption) OrderOption

ByRedeemedAt orders the results by the redeemed_at field.

func ByRedemptionCodeField

func ByRedemptionCodeField(field string, opts ...sql.OrderTermOption) OrderOption

ByRedemptionCodeField orders the results by redemption_code field.

func ByRedemptionCodeID

func ByRedemptionCodeID(opts ...sql.OrderTermOption) OrderOption

ByRedemptionCodeID orders the results by the redemption_code_id field.

func BySubscribeID

func BySubscribeID(opts ...sql.OrderTermOption) OrderOption

BySubscribeID orders the results by the subscribe_id field.

func ByUnitTime

func ByUnitTime(opts ...sql.OrderTermOption) OrderOption

ByUnitTime orders the results by the unit_time field.

func ByUserField

func ByUserField(field string, opts ...sql.OrderTermOption) OrderOption

ByUserField orders the results by user field.

func ByUserID

func ByUserID(opts ...sql.OrderTermOption) OrderOption

ByUserID orders the results by the user_id field.

Jump to