Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.ProxyTrafficLog) predicate.ProxyTrafficLog
- func Download(v int64) predicate.ProxyTrafficLog
- func DownloadEQ(v int64) predicate.ProxyTrafficLog
- func DownloadGT(v int64) predicate.ProxyTrafficLog
- func DownloadGTE(v int64) predicate.ProxyTrafficLog
- func DownloadIn(vs ...int64) predicate.ProxyTrafficLog
- func DownloadLT(v int64) predicate.ProxyTrafficLog
- func DownloadLTE(v int64) predicate.ProxyTrafficLog
- func DownloadNEQ(v int64) predicate.ProxyTrafficLog
- func DownloadNotIn(vs ...int64) predicate.ProxyTrafficLog
- func ID(id int64) predicate.ProxyTrafficLog
- func IDEQ(id int64) predicate.ProxyTrafficLog
- func IDGT(id int64) predicate.ProxyTrafficLog
- func IDGTE(id int64) predicate.ProxyTrafficLog
- func IDIn(ids ...int64) predicate.ProxyTrafficLog
- func IDLT(id int64) predicate.ProxyTrafficLog
- func IDLTE(id int64) predicate.ProxyTrafficLog
- func IDNEQ(id int64) predicate.ProxyTrafficLog
- func IDNotIn(ids ...int64) predicate.ProxyTrafficLog
- func Not(p predicate.ProxyTrafficLog) predicate.ProxyTrafficLog
- func Or(predicates ...predicate.ProxyTrafficLog) predicate.ProxyTrafficLog
- func ServerID(v int64) predicate.ProxyTrafficLog
- func ServerIDEQ(v int64) predicate.ProxyTrafficLog
- func ServerIDGT(v int64) predicate.ProxyTrafficLog
- func ServerIDGTE(v int64) predicate.ProxyTrafficLog
- func ServerIDIn(vs ...int64) predicate.ProxyTrafficLog
- func ServerIDLT(v int64) predicate.ProxyTrafficLog
- func ServerIDLTE(v int64) predicate.ProxyTrafficLog
- func ServerIDNEQ(v int64) predicate.ProxyTrafficLog
- func ServerIDNotIn(vs ...int64) predicate.ProxyTrafficLog
- func SubscribeID(v int64) predicate.ProxyTrafficLog
- func SubscribeIDEQ(v int64) predicate.ProxyTrafficLog
- func SubscribeIDGT(v int64) predicate.ProxyTrafficLog
- func SubscribeIDGTE(v int64) predicate.ProxyTrafficLog
- func SubscribeIDIn(vs ...int64) predicate.ProxyTrafficLog
- func SubscribeIDLT(v int64) predicate.ProxyTrafficLog
- func SubscribeIDLTE(v int64) predicate.ProxyTrafficLog
- func SubscribeIDNEQ(v int64) predicate.ProxyTrafficLog
- func SubscribeIDNotIn(vs ...int64) predicate.ProxyTrafficLog
- func Timestamp(v time.Time) predicate.ProxyTrafficLog
- func TimestampEQ(v time.Time) predicate.ProxyTrafficLog
- func TimestampGT(v time.Time) predicate.ProxyTrafficLog
- func TimestampGTE(v time.Time) predicate.ProxyTrafficLog
- func TimestampIn(vs ...time.Time) predicate.ProxyTrafficLog
- func TimestampLT(v time.Time) predicate.ProxyTrafficLog
- func TimestampLTE(v time.Time) predicate.ProxyTrafficLog
- func TimestampNEQ(v time.Time) predicate.ProxyTrafficLog
- func TimestampNotIn(vs ...time.Time) predicate.ProxyTrafficLog
- func Upload(v int64) predicate.ProxyTrafficLog
- func UploadEQ(v int64) predicate.ProxyTrafficLog
- func UploadGT(v int64) predicate.ProxyTrafficLog
- func UploadGTE(v int64) predicate.ProxyTrafficLog
- func UploadIn(vs ...int64) predicate.ProxyTrafficLog
- func UploadLT(v int64) predicate.ProxyTrafficLog
- func UploadLTE(v int64) predicate.ProxyTrafficLog
- func UploadNEQ(v int64) predicate.ProxyTrafficLog
- func UploadNotIn(vs ...int64) predicate.ProxyTrafficLog
- func UserID(v int64) predicate.ProxyTrafficLog
- func UserIDEQ(v int64) predicate.ProxyTrafficLog
- func UserIDGT(v int64) predicate.ProxyTrafficLog
- func UserIDGTE(v int64) predicate.ProxyTrafficLog
- func UserIDIn(vs ...int64) predicate.ProxyTrafficLog
- func UserIDLT(v int64) predicate.ProxyTrafficLog
- func UserIDLTE(v int64) predicate.ProxyTrafficLog
- func UserIDNEQ(v int64) predicate.ProxyTrafficLog
- func UserIDNotIn(vs ...int64) predicate.ProxyTrafficLog
- func ValidColumn(column string) bool
- type OrderOption
- func ByDownload(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByServerID(opts ...sql.OrderTermOption) OrderOption
- func BySubscribeID(opts ...sql.OrderTermOption) OrderOption
- func ByTimestamp(opts ...sql.OrderTermOption) OrderOption
- func ByUpload(opts ...sql.OrderTermOption) OrderOption
- func ByUserID(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the proxytrafficlog type in the database. Label = "proxy_traffic_log" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldServerID holds the string denoting the server_id field in the database. FieldServerID = "server_id" // FieldUserID holds the string denoting the user_id field in the database. FieldUserID = "user_id" // FieldSubscribeID holds the string denoting the subscribe_id field in the database. FieldSubscribeID = "subscribe_id" // FieldDownload holds the string denoting the download field in the database. FieldDownload = "download" // FieldUpload holds the string denoting the upload field in the database. FieldUpload = "upload" // FieldTimestamp holds the string denoting the timestamp field in the database. FieldTimestamp = "timestamp" // Table holds the table name of the proxytrafficlog in the database. Table = "traffic_log" )
Variables ¶
var ( // DefaultDownload holds the default value on creation for the "download" field. DefaultDownload int64 // DefaultUpload holds the default value on creation for the "upload" field. DefaultUpload int64 // DefaultTimestamp holds the default value on creation for the "timestamp" field. DefaultTimestamp func() time.Time )
var Columns = []string{ FieldID, FieldServerID, FieldUserID, FieldSubscribeID, FieldDownload, FieldUpload, FieldTimestamp, }
Columns holds all SQL columns for proxytrafficlog fields.
Functions ¶
func And ¶
func And(predicates ...predicate.ProxyTrafficLog) predicate.ProxyTrafficLog
And groups predicates with the AND operator between them.
func Download ¶
func Download(v int64) predicate.ProxyTrafficLog
Download applies equality check predicate on the "download" field. It's identical to DownloadEQ.
func DownloadEQ ¶
func DownloadEQ(v int64) predicate.ProxyTrafficLog
DownloadEQ applies the EQ predicate on the "download" field.
func DownloadGT ¶
func DownloadGT(v int64) predicate.ProxyTrafficLog
DownloadGT applies the GT predicate on the "download" field.
func DownloadGTE ¶
func DownloadGTE(v int64) predicate.ProxyTrafficLog
DownloadGTE applies the GTE predicate on the "download" field.
func DownloadIn ¶
func DownloadIn(vs ...int64) predicate.ProxyTrafficLog
DownloadIn applies the In predicate on the "download" field.
func DownloadLT ¶
func DownloadLT(v int64) predicate.ProxyTrafficLog
DownloadLT applies the LT predicate on the "download" field.
func DownloadLTE ¶
func DownloadLTE(v int64) predicate.ProxyTrafficLog
DownloadLTE applies the LTE predicate on the "download" field.
func DownloadNEQ ¶
func DownloadNEQ(v int64) predicate.ProxyTrafficLog
DownloadNEQ applies the NEQ predicate on the "download" field.
func DownloadNotIn ¶
func DownloadNotIn(vs ...int64) predicate.ProxyTrafficLog
DownloadNotIn applies the NotIn predicate on the "download" field.
func IDEQ ¶
func IDEQ(id int64) predicate.ProxyTrafficLog
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id int64) predicate.ProxyTrafficLog
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id int64) predicate.ProxyTrafficLog
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...int64) predicate.ProxyTrafficLog
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id int64) predicate.ProxyTrafficLog
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id int64) predicate.ProxyTrafficLog
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id int64) predicate.ProxyTrafficLog
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...int64) predicate.ProxyTrafficLog
IDNotIn applies the NotIn predicate on the ID field.
func Not ¶
func Not(p predicate.ProxyTrafficLog) predicate.ProxyTrafficLog
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.ProxyTrafficLog) predicate.ProxyTrafficLog
Or groups predicates with the OR operator between them.
func ServerID ¶
func ServerID(v int64) predicate.ProxyTrafficLog
ServerID applies equality check predicate on the "server_id" field. It's identical to ServerIDEQ.
func ServerIDEQ ¶
func ServerIDEQ(v int64) predicate.ProxyTrafficLog
ServerIDEQ applies the EQ predicate on the "server_id" field.
func ServerIDGT ¶
func ServerIDGT(v int64) predicate.ProxyTrafficLog
ServerIDGT applies the GT predicate on the "server_id" field.
func ServerIDGTE ¶
func ServerIDGTE(v int64) predicate.ProxyTrafficLog
ServerIDGTE applies the GTE predicate on the "server_id" field.
func ServerIDIn ¶
func ServerIDIn(vs ...int64) predicate.ProxyTrafficLog
ServerIDIn applies the In predicate on the "server_id" field.
func ServerIDLT ¶
func ServerIDLT(v int64) predicate.ProxyTrafficLog
ServerIDLT applies the LT predicate on the "server_id" field.
func ServerIDLTE ¶
func ServerIDLTE(v int64) predicate.ProxyTrafficLog
ServerIDLTE applies the LTE predicate on the "server_id" field.
func ServerIDNEQ ¶
func ServerIDNEQ(v int64) predicate.ProxyTrafficLog
ServerIDNEQ applies the NEQ predicate on the "server_id" field.
func ServerIDNotIn ¶
func ServerIDNotIn(vs ...int64) predicate.ProxyTrafficLog
ServerIDNotIn applies the NotIn predicate on the "server_id" field.
func SubscribeID ¶
func SubscribeID(v int64) predicate.ProxyTrafficLog
SubscribeID applies equality check predicate on the "subscribe_id" field. It's identical to SubscribeIDEQ.
func SubscribeIDEQ ¶
func SubscribeIDEQ(v int64) predicate.ProxyTrafficLog
SubscribeIDEQ applies the EQ predicate on the "subscribe_id" field.
func SubscribeIDGT ¶
func SubscribeIDGT(v int64) predicate.ProxyTrafficLog
SubscribeIDGT applies the GT predicate on the "subscribe_id" field.
func SubscribeIDGTE ¶
func SubscribeIDGTE(v int64) predicate.ProxyTrafficLog
SubscribeIDGTE applies the GTE predicate on the "subscribe_id" field.
func SubscribeIDIn ¶
func SubscribeIDIn(vs ...int64) predicate.ProxyTrafficLog
SubscribeIDIn applies the In predicate on the "subscribe_id" field.
func SubscribeIDLT ¶
func SubscribeIDLT(v int64) predicate.ProxyTrafficLog
SubscribeIDLT applies the LT predicate on the "subscribe_id" field.
func SubscribeIDLTE ¶
func SubscribeIDLTE(v int64) predicate.ProxyTrafficLog
SubscribeIDLTE applies the LTE predicate on the "subscribe_id" field.
func SubscribeIDNEQ ¶
func SubscribeIDNEQ(v int64) predicate.ProxyTrafficLog
SubscribeIDNEQ applies the NEQ predicate on the "subscribe_id" field.
func SubscribeIDNotIn ¶
func SubscribeIDNotIn(vs ...int64) predicate.ProxyTrafficLog
SubscribeIDNotIn applies the NotIn predicate on the "subscribe_id" field.
func Timestamp ¶
func Timestamp(v time.Time) predicate.ProxyTrafficLog
Timestamp applies equality check predicate on the "timestamp" field. It's identical to TimestampEQ.
func TimestampEQ ¶
func TimestampEQ(v time.Time) predicate.ProxyTrafficLog
TimestampEQ applies the EQ predicate on the "timestamp" field.
func TimestampGT ¶
func TimestampGT(v time.Time) predicate.ProxyTrafficLog
TimestampGT applies the GT predicate on the "timestamp" field.
func TimestampGTE ¶
func TimestampGTE(v time.Time) predicate.ProxyTrafficLog
TimestampGTE applies the GTE predicate on the "timestamp" field.
func TimestampIn ¶
func TimestampIn(vs ...time.Time) predicate.ProxyTrafficLog
TimestampIn applies the In predicate on the "timestamp" field.
func TimestampLT ¶
func TimestampLT(v time.Time) predicate.ProxyTrafficLog
TimestampLT applies the LT predicate on the "timestamp" field.
func TimestampLTE ¶
func TimestampLTE(v time.Time) predicate.ProxyTrafficLog
TimestampLTE applies the LTE predicate on the "timestamp" field.
func TimestampNEQ ¶
func TimestampNEQ(v time.Time) predicate.ProxyTrafficLog
TimestampNEQ applies the NEQ predicate on the "timestamp" field.
func TimestampNotIn ¶
func TimestampNotIn(vs ...time.Time) predicate.ProxyTrafficLog
TimestampNotIn applies the NotIn predicate on the "timestamp" field.
func Upload ¶
func Upload(v int64) predicate.ProxyTrafficLog
Upload applies equality check predicate on the "upload" field. It's identical to UploadEQ.
func UploadEQ ¶
func UploadEQ(v int64) predicate.ProxyTrafficLog
UploadEQ applies the EQ predicate on the "upload" field.
func UploadGT ¶
func UploadGT(v int64) predicate.ProxyTrafficLog
UploadGT applies the GT predicate on the "upload" field.
func UploadGTE ¶
func UploadGTE(v int64) predicate.ProxyTrafficLog
UploadGTE applies the GTE predicate on the "upload" field.
func UploadIn ¶
func UploadIn(vs ...int64) predicate.ProxyTrafficLog
UploadIn applies the In predicate on the "upload" field.
func UploadLT ¶
func UploadLT(v int64) predicate.ProxyTrafficLog
UploadLT applies the LT predicate on the "upload" field.
func UploadLTE ¶
func UploadLTE(v int64) predicate.ProxyTrafficLog
UploadLTE applies the LTE predicate on the "upload" field.
func UploadNEQ ¶
func UploadNEQ(v int64) predicate.ProxyTrafficLog
UploadNEQ applies the NEQ predicate on the "upload" field.
func UploadNotIn ¶
func UploadNotIn(vs ...int64) predicate.ProxyTrafficLog
UploadNotIn applies the NotIn predicate on the "upload" field.
func UserID ¶
func UserID(v int64) predicate.ProxyTrafficLog
UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.
func UserIDEQ ¶
func UserIDEQ(v int64) predicate.ProxyTrafficLog
UserIDEQ applies the EQ predicate on the "user_id" field.
func UserIDGT ¶
func UserIDGT(v int64) predicate.ProxyTrafficLog
UserIDGT applies the GT predicate on the "user_id" field.
func UserIDGTE ¶
func UserIDGTE(v int64) predicate.ProxyTrafficLog
UserIDGTE applies the GTE predicate on the "user_id" field.
func UserIDIn ¶
func UserIDIn(vs ...int64) predicate.ProxyTrafficLog
UserIDIn applies the In predicate on the "user_id" field.
func UserIDLT ¶
func UserIDLT(v int64) predicate.ProxyTrafficLog
UserIDLT applies the LT predicate on the "user_id" field.
func UserIDLTE ¶
func UserIDLTE(v int64) predicate.ProxyTrafficLog
UserIDLTE applies the LTE predicate on the "user_id" field.
func UserIDNEQ ¶
func UserIDNEQ(v int64) predicate.ProxyTrafficLog
UserIDNEQ applies the NEQ predicate on the "user_id" field.
func UserIDNotIn ¶
func UserIDNotIn(vs ...int64) predicate.ProxyTrafficLog
UserIDNotIn applies the NotIn predicate on the "user_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the ProxyTrafficLog queries.
func ByDownload ¶
func ByDownload(opts ...sql.OrderTermOption) OrderOption
ByDownload orders the results by the download field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByServerID ¶
func ByServerID(opts ...sql.OrderTermOption) OrderOption
ByServerID orders the results by the server_id field.
func BySubscribeID ¶
func BySubscribeID(opts ...sql.OrderTermOption) OrderOption
BySubscribeID orders the results by the subscribe_id field.
func ByTimestamp ¶
func ByTimestamp(opts ...sql.OrderTermOption) OrderOption
ByTimestamp orders the results by the timestamp field.
func ByUpload ¶
func ByUpload(opts ...sql.OrderTermOption) OrderOption
ByUpload orders the results by the upload field.
func ByUserID ¶
func ByUserID(opts ...sql.OrderTermOption) OrderOption
ByUserID orders the results by the user_id field.