Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.ProxyUserSubscribe) predicate.ProxyUserSubscribe
- func CreatedAt(v time.Time) predicate.ProxyUserSubscribe
- func CreatedAtEQ(v time.Time) predicate.ProxyUserSubscribe
- func CreatedAtGT(v time.Time) predicate.ProxyUserSubscribe
- func CreatedAtGTE(v time.Time) predicate.ProxyUserSubscribe
- func CreatedAtIn(vs ...time.Time) predicate.ProxyUserSubscribe
- func CreatedAtLT(v time.Time) predicate.ProxyUserSubscribe
- func CreatedAtLTE(v time.Time) predicate.ProxyUserSubscribe
- func CreatedAtNEQ(v time.Time) predicate.ProxyUserSubscribe
- func CreatedAtNotIn(vs ...time.Time) predicate.ProxyUserSubscribe
- func Download(v int64) predicate.ProxyUserSubscribe
- func DownloadEQ(v int64) predicate.ProxyUserSubscribe
- func DownloadGT(v int64) predicate.ProxyUserSubscribe
- func DownloadGTE(v int64) predicate.ProxyUserSubscribe
- func DownloadIn(vs ...int64) predicate.ProxyUserSubscribe
- func DownloadIsNil() predicate.ProxyUserSubscribe
- func DownloadLT(v int64) predicate.ProxyUserSubscribe
- func DownloadLTE(v int64) predicate.ProxyUserSubscribe
- func DownloadNEQ(v int64) predicate.ProxyUserSubscribe
- func DownloadNotIn(vs ...int64) predicate.ProxyUserSubscribe
- func DownloadNotNil() predicate.ProxyUserSubscribe
- func ExpireTime(v time.Time) predicate.ProxyUserSubscribe
- func ExpireTimeEQ(v time.Time) predicate.ProxyUserSubscribe
- func ExpireTimeGT(v time.Time) predicate.ProxyUserSubscribe
- func ExpireTimeGTE(v time.Time) predicate.ProxyUserSubscribe
- func ExpireTimeIn(vs ...time.Time) predicate.ProxyUserSubscribe
- func ExpireTimeIsNil() predicate.ProxyUserSubscribe
- func ExpireTimeLT(v time.Time) predicate.ProxyUserSubscribe
- func ExpireTimeLTE(v time.Time) predicate.ProxyUserSubscribe
- func ExpireTimeNEQ(v time.Time) predicate.ProxyUserSubscribe
- func ExpireTimeNotIn(vs ...time.Time) predicate.ProxyUserSubscribe
- func ExpireTimeNotNil() predicate.ProxyUserSubscribe
- func ExpiredDownload(v int64) predicate.ProxyUserSubscribe
- func ExpiredDownloadEQ(v int64) predicate.ProxyUserSubscribe
- func ExpiredDownloadGT(v int64) predicate.ProxyUserSubscribe
- func ExpiredDownloadGTE(v int64) predicate.ProxyUserSubscribe
- func ExpiredDownloadIn(vs ...int64) predicate.ProxyUserSubscribe
- func ExpiredDownloadIsNil() predicate.ProxyUserSubscribe
- func ExpiredDownloadLT(v int64) predicate.ProxyUserSubscribe
- func ExpiredDownloadLTE(v int64) predicate.ProxyUserSubscribe
- func ExpiredDownloadNEQ(v int64) predicate.ProxyUserSubscribe
- func ExpiredDownloadNotIn(vs ...int64) predicate.ProxyUserSubscribe
- func ExpiredDownloadNotNil() predicate.ProxyUserSubscribe
- func ExpiredUpload(v int64) predicate.ProxyUserSubscribe
- func ExpiredUploadEQ(v int64) predicate.ProxyUserSubscribe
- func ExpiredUploadGT(v int64) predicate.ProxyUserSubscribe
- func ExpiredUploadGTE(v int64) predicate.ProxyUserSubscribe
- func ExpiredUploadIn(vs ...int64) predicate.ProxyUserSubscribe
- func ExpiredUploadIsNil() predicate.ProxyUserSubscribe
- func ExpiredUploadLT(v int64) predicate.ProxyUserSubscribe
- func ExpiredUploadLTE(v int64) predicate.ProxyUserSubscribe
- func ExpiredUploadNEQ(v int64) predicate.ProxyUserSubscribe
- func ExpiredUploadNotIn(vs ...int64) predicate.ProxyUserSubscribe
- func ExpiredUploadNotNil() predicate.ProxyUserSubscribe
- func FinishedAt(v time.Time) predicate.ProxyUserSubscribe
- func FinishedAtEQ(v time.Time) predicate.ProxyUserSubscribe
- func FinishedAtGT(v time.Time) predicate.ProxyUserSubscribe
- func FinishedAtGTE(v time.Time) predicate.ProxyUserSubscribe
- func FinishedAtIn(vs ...time.Time) predicate.ProxyUserSubscribe
- func FinishedAtIsNil() predicate.ProxyUserSubscribe
- func FinishedAtLT(v time.Time) predicate.ProxyUserSubscribe
- func FinishedAtLTE(v time.Time) predicate.ProxyUserSubscribe
- func FinishedAtNEQ(v time.Time) predicate.ProxyUserSubscribe
- func FinishedAtNotIn(vs ...time.Time) predicate.ProxyUserSubscribe
- func FinishedAtNotNil() predicate.ProxyUserSubscribe
- func GroupLocked(v bool) predicate.ProxyUserSubscribe
- func GroupLockedEQ(v bool) predicate.ProxyUserSubscribe
- func GroupLockedNEQ(v bool) predicate.ProxyUserSubscribe
- func ID(id int64) predicate.ProxyUserSubscribe
- func IDEQ(id int64) predicate.ProxyUserSubscribe
- func IDGT(id int64) predicate.ProxyUserSubscribe
- func IDGTE(id int64) predicate.ProxyUserSubscribe
- func IDIn(ids ...int64) predicate.ProxyUserSubscribe
- func IDLT(id int64) predicate.ProxyUserSubscribe
- func IDLTE(id int64) predicate.ProxyUserSubscribe
- func IDNEQ(id int64) predicate.ProxyUserSubscribe
- func IDNotIn(ids ...int64) predicate.ProxyUserSubscribe
- func NodeGroupID(v int64) predicate.ProxyUserSubscribe
- func NodeGroupIDEQ(v int64) predicate.ProxyUserSubscribe
- func NodeGroupIDGT(v int64) predicate.ProxyUserSubscribe
- func NodeGroupIDGTE(v int64) predicate.ProxyUserSubscribe
- func NodeGroupIDIn(vs ...int64) predicate.ProxyUserSubscribe
- func NodeGroupIDLT(v int64) predicate.ProxyUserSubscribe
- func NodeGroupIDLTE(v int64) predicate.ProxyUserSubscribe
- func NodeGroupIDNEQ(v int64) predicate.ProxyUserSubscribe
- func NodeGroupIDNotIn(vs ...int64) predicate.ProxyUserSubscribe
- func Not(p predicate.ProxyUserSubscribe) predicate.ProxyUserSubscribe
- func Note(v string) predicate.ProxyUserSubscribe
- func NoteContains(v string) predicate.ProxyUserSubscribe
- func NoteContainsFold(v string) predicate.ProxyUserSubscribe
- func NoteEQ(v string) predicate.ProxyUserSubscribe
- func NoteEqualFold(v string) predicate.ProxyUserSubscribe
- func NoteGT(v string) predicate.ProxyUserSubscribe
- func NoteGTE(v string) predicate.ProxyUserSubscribe
- func NoteHasPrefix(v string) predicate.ProxyUserSubscribe
- func NoteHasSuffix(v string) predicate.ProxyUserSubscribe
- func NoteIn(vs ...string) predicate.ProxyUserSubscribe
- func NoteIsNil() predicate.ProxyUserSubscribe
- func NoteLT(v string) predicate.ProxyUserSubscribe
- func NoteLTE(v string) predicate.ProxyUserSubscribe
- func NoteNEQ(v string) predicate.ProxyUserSubscribe
- func NoteNotIn(vs ...string) predicate.ProxyUserSubscribe
- func NoteNotNil() predicate.ProxyUserSubscribe
- func Or(predicates ...predicate.ProxyUserSubscribe) predicate.ProxyUserSubscribe
- func OrderID(v int64) predicate.ProxyUserSubscribe
- func OrderIDEQ(v int64) predicate.ProxyUserSubscribe
- func OrderIDGT(v int64) predicate.ProxyUserSubscribe
- func OrderIDGTE(v int64) predicate.ProxyUserSubscribe
- func OrderIDIn(vs ...int64) predicate.ProxyUserSubscribe
- func OrderIDLT(v int64) predicate.ProxyUserSubscribe
- func OrderIDLTE(v int64) predicate.ProxyUserSubscribe
- func OrderIDNEQ(v int64) predicate.ProxyUserSubscribe
- func OrderIDNotIn(vs ...int64) predicate.ProxyUserSubscribe
- func StartTime(v time.Time) predicate.ProxyUserSubscribe
- func StartTimeEQ(v time.Time) predicate.ProxyUserSubscribe
- func StartTimeGT(v time.Time) predicate.ProxyUserSubscribe
- func StartTimeGTE(v time.Time) predicate.ProxyUserSubscribe
- func StartTimeIn(vs ...time.Time) predicate.ProxyUserSubscribe
- func StartTimeLT(v time.Time) predicate.ProxyUserSubscribe
- func StartTimeLTE(v time.Time) predicate.ProxyUserSubscribe
- func StartTimeNEQ(v time.Time) predicate.ProxyUserSubscribe
- func StartTimeNotIn(vs ...time.Time) predicate.ProxyUserSubscribe
- func Status(v int8) predicate.ProxyUserSubscribe
- func StatusEQ(v int8) predicate.ProxyUserSubscribe
- func StatusGT(v int8) predicate.ProxyUserSubscribe
- func StatusGTE(v int8) predicate.ProxyUserSubscribe
- func StatusIn(vs ...int8) predicate.ProxyUserSubscribe
- func StatusIsNil() predicate.ProxyUserSubscribe
- func StatusLT(v int8) predicate.ProxyUserSubscribe
- func StatusLTE(v int8) predicate.ProxyUserSubscribe
- func StatusNEQ(v int8) predicate.ProxyUserSubscribe
- func StatusNotIn(vs ...int8) predicate.ProxyUserSubscribe
- func StatusNotNil() predicate.ProxyUserSubscribe
- func SubscribeID(v int64) predicate.ProxyUserSubscribe
- func SubscribeIDEQ(v int64) predicate.ProxyUserSubscribe
- func SubscribeIDGT(v int64) predicate.ProxyUserSubscribe
- func SubscribeIDGTE(v int64) predicate.ProxyUserSubscribe
- func SubscribeIDIn(vs ...int64) predicate.ProxyUserSubscribe
- func SubscribeIDLT(v int64) predicate.ProxyUserSubscribe
- func SubscribeIDLTE(v int64) predicate.ProxyUserSubscribe
- func SubscribeIDNEQ(v int64) predicate.ProxyUserSubscribe
- func SubscribeIDNotIn(vs ...int64) predicate.ProxyUserSubscribe
- func Token(v string) predicate.ProxyUserSubscribe
- func TokenContains(v string) predicate.ProxyUserSubscribe
- func TokenContainsFold(v string) predicate.ProxyUserSubscribe
- func TokenEQ(v string) predicate.ProxyUserSubscribe
- func TokenEqualFold(v string) predicate.ProxyUserSubscribe
- func TokenGT(v string) predicate.ProxyUserSubscribe
- func TokenGTE(v string) predicate.ProxyUserSubscribe
- func TokenHasPrefix(v string) predicate.ProxyUserSubscribe
- func TokenHasSuffix(v string) predicate.ProxyUserSubscribe
- func TokenIn(vs ...string) predicate.ProxyUserSubscribe
- func TokenIsNil() predicate.ProxyUserSubscribe
- func TokenLT(v string) predicate.ProxyUserSubscribe
- func TokenLTE(v string) predicate.ProxyUserSubscribe
- func TokenNEQ(v string) predicate.ProxyUserSubscribe
- func TokenNotIn(vs ...string) predicate.ProxyUserSubscribe
- func TokenNotNil() predicate.ProxyUserSubscribe
- func Traffic(v int64) predicate.ProxyUserSubscribe
- func TrafficEQ(v int64) predicate.ProxyUserSubscribe
- func TrafficGT(v int64) predicate.ProxyUserSubscribe
- func TrafficGTE(v int64) predicate.ProxyUserSubscribe
- func TrafficIn(vs ...int64) predicate.ProxyUserSubscribe
- func TrafficIsNil() predicate.ProxyUserSubscribe
- func TrafficLT(v int64) predicate.ProxyUserSubscribe
- func TrafficLTE(v int64) predicate.ProxyUserSubscribe
- func TrafficNEQ(v int64) predicate.ProxyUserSubscribe
- func TrafficNotIn(vs ...int64) predicate.ProxyUserSubscribe
- func TrafficNotNil() predicate.ProxyUserSubscribe
- func UUID(v string) predicate.ProxyUserSubscribe
- func UUIDContains(v string) predicate.ProxyUserSubscribe
- func UUIDContainsFold(v string) predicate.ProxyUserSubscribe
- func UUIDEQ(v string) predicate.ProxyUserSubscribe
- func UUIDEqualFold(v string) predicate.ProxyUserSubscribe
- func UUIDGT(v string) predicate.ProxyUserSubscribe
- func UUIDGTE(v string) predicate.ProxyUserSubscribe
- func UUIDHasPrefix(v string) predicate.ProxyUserSubscribe
- func UUIDHasSuffix(v string) predicate.ProxyUserSubscribe
- func UUIDIn(vs ...string) predicate.ProxyUserSubscribe
- func UUIDIsNil() predicate.ProxyUserSubscribe
- func UUIDLT(v string) predicate.ProxyUserSubscribe
- func UUIDLTE(v string) predicate.ProxyUserSubscribe
- func UUIDNEQ(v string) predicate.ProxyUserSubscribe
- func UUIDNotIn(vs ...string) predicate.ProxyUserSubscribe
- func UUIDNotNil() predicate.ProxyUserSubscribe
- func UpdatedAt(v time.Time) predicate.ProxyUserSubscribe
- func UpdatedAtEQ(v time.Time) predicate.ProxyUserSubscribe
- func UpdatedAtGT(v time.Time) predicate.ProxyUserSubscribe
- func UpdatedAtGTE(v time.Time) predicate.ProxyUserSubscribe
- func UpdatedAtIn(vs ...time.Time) predicate.ProxyUserSubscribe
- func UpdatedAtLT(v time.Time) predicate.ProxyUserSubscribe
- func UpdatedAtLTE(v time.Time) predicate.ProxyUserSubscribe
- func UpdatedAtNEQ(v time.Time) predicate.ProxyUserSubscribe
- func UpdatedAtNotIn(vs ...time.Time) predicate.ProxyUserSubscribe
- func Upload(v int64) predicate.ProxyUserSubscribe
- func UploadEQ(v int64) predicate.ProxyUserSubscribe
- func UploadGT(v int64) predicate.ProxyUserSubscribe
- func UploadGTE(v int64) predicate.ProxyUserSubscribe
- func UploadIn(vs ...int64) predicate.ProxyUserSubscribe
- func UploadIsNil() predicate.ProxyUserSubscribe
- func UploadLT(v int64) predicate.ProxyUserSubscribe
- func UploadLTE(v int64) predicate.ProxyUserSubscribe
- func UploadNEQ(v int64) predicate.ProxyUserSubscribe
- func UploadNotIn(vs ...int64) predicate.ProxyUserSubscribe
- func UploadNotNil() predicate.ProxyUserSubscribe
- func UserID(v int64) predicate.ProxyUserSubscribe
- func UserIDEQ(v int64) predicate.ProxyUserSubscribe
- func UserIDGT(v int64) predicate.ProxyUserSubscribe
- func UserIDGTE(v int64) predicate.ProxyUserSubscribe
- func UserIDIn(vs ...int64) predicate.ProxyUserSubscribe
- func UserIDLT(v int64) predicate.ProxyUserSubscribe
- func UserIDLTE(v int64) predicate.ProxyUserSubscribe
- func UserIDNEQ(v int64) predicate.ProxyUserSubscribe
- func UserIDNotIn(vs ...int64) predicate.ProxyUserSubscribe
- func ValidColumn(column string) bool
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDownload(opts ...sql.OrderTermOption) OrderOption
- func ByExpireTime(opts ...sql.OrderTermOption) OrderOption
- func ByExpiredDownload(opts ...sql.OrderTermOption) OrderOption
- func ByExpiredUpload(opts ...sql.OrderTermOption) OrderOption
- func ByFinishedAt(opts ...sql.OrderTermOption) OrderOption
- func ByGroupLocked(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByNodeGroupID(opts ...sql.OrderTermOption) OrderOption
- func ByNote(opts ...sql.OrderTermOption) OrderOption
- func ByOrderID(opts ...sql.OrderTermOption) OrderOption
- func ByStartTime(opts ...sql.OrderTermOption) OrderOption
- func ByStatus(opts ...sql.OrderTermOption) OrderOption
- func BySubscribeID(opts ...sql.OrderTermOption) OrderOption
- func ByToken(opts ...sql.OrderTermOption) OrderOption
- func ByTraffic(opts ...sql.OrderTermOption) OrderOption
- func ByUUID(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpload(opts ...sql.OrderTermOption) OrderOption
- func ByUserID(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the proxyusersubscribe type in the database. Label = "proxy_user_subscribe" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldUserID holds the string denoting the user_id field in the database. FieldUserID = "user_id" // FieldOrderID holds the string denoting the order_id field in the database. FieldOrderID = "order_id" // FieldSubscribeID holds the string denoting the subscribe_id field in the database. FieldSubscribeID = "subscribe_id" // FieldNodeGroupID holds the string denoting the node_group_id field in the database. FieldNodeGroupID = "node_group_id" // FieldGroupLocked holds the string denoting the group_locked field in the database. FieldGroupLocked = "group_locked" // FieldStartTime holds the string denoting the start_time field in the database. FieldStartTime = "start_time" // FieldExpireTime holds the string denoting the expire_time field in the database. FieldExpireTime = "expire_time" // FieldFinishedAt holds the string denoting the finished_at field in the database. FieldFinishedAt = "finished_at" // FieldTraffic holds the string denoting the traffic field in the database. FieldTraffic = "traffic" // FieldDownload holds the string denoting the download field in the database. FieldDownload = "download" // FieldUpload holds the string denoting the upload field in the database. FieldUpload = "upload" // FieldExpiredDownload holds the string denoting the expired_download field in the database. FieldExpiredDownload = "expired_download" // FieldExpiredUpload holds the string denoting the expired_upload field in the database. FieldExpiredUpload = "expired_upload" // FieldToken holds the string denoting the token field in the database. FieldToken = "token" // FieldUUID holds the string denoting the uuid field in the database. FieldUUID = "uuid" // FieldStatus holds the string denoting the status field in the database. FieldStatus = "status" // FieldNote holds the string denoting the note field in the database. FieldNote = "note" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // Table holds the table name of the proxyusersubscribe in the database. Table = "user_subscribe" )
Variables ¶
var ( // DefaultNodeGroupID holds the default value on creation for the "node_group_id" field. DefaultNodeGroupID int64 // DefaultGroupLocked holds the default value on creation for the "group_locked" field. DefaultGroupLocked bool // DefaultTraffic holds the default value on creation for the "traffic" field. DefaultTraffic int64 // DefaultDownload holds the default value on creation for the "download" field. DefaultDownload int64 // DefaultUpload holds the default value on creation for the "upload" field. DefaultUpload int64 // DefaultExpiredDownload holds the default value on creation for the "expired_download" field. DefaultExpiredDownload int64 // DefaultExpiredUpload holds the default value on creation for the "expired_upload" field. DefaultExpiredUpload int64 // TokenValidator is a validator for the "token" field. It is called by the builders before save. TokenValidator func(string) error // UUIDValidator is a validator for the "uuid" field. It is called by the builders before save. UUIDValidator func(string) error // DefaultStatus holds the default value on creation for the "status" field. DefaultStatus int8 // NoteValidator is a validator for the "note" field. It is called by the builders before save. NoteValidator func(string) error // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // IDValidator is a validator for the "id" field. It is called by the builders before save. IDValidator func(int64) error )
var Columns = []string{ FieldID, FieldUserID, FieldOrderID, FieldSubscribeID, FieldNodeGroupID, FieldGroupLocked, FieldStartTime, FieldExpireTime, FieldFinishedAt, FieldTraffic, FieldDownload, FieldUpload, FieldExpiredDownload, FieldExpiredUpload, FieldToken, FieldUUID, FieldStatus, FieldNote, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for proxyusersubscribe fields.
Functions ¶
func And ¶
func And(predicates ...predicate.ProxyUserSubscribe) predicate.ProxyUserSubscribe
And groups predicates with the AND operator between them.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.ProxyUserSubscribe
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.ProxyUserSubscribe
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.ProxyUserSubscribe
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.ProxyUserSubscribe
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.ProxyUserSubscribe
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.ProxyUserSubscribe
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.ProxyUserSubscribe
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.ProxyUserSubscribe
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.ProxyUserSubscribe
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func Download ¶
func Download(v int64) predicate.ProxyUserSubscribe
Download applies equality check predicate on the "download" field. It's identical to DownloadEQ.
func DownloadEQ ¶
func DownloadEQ(v int64) predicate.ProxyUserSubscribe
DownloadEQ applies the EQ predicate on the "download" field.
func DownloadGT ¶
func DownloadGT(v int64) predicate.ProxyUserSubscribe
DownloadGT applies the GT predicate on the "download" field.
func DownloadGTE ¶
func DownloadGTE(v int64) predicate.ProxyUserSubscribe
DownloadGTE applies the GTE predicate on the "download" field.
func DownloadIn ¶
func DownloadIn(vs ...int64) predicate.ProxyUserSubscribe
DownloadIn applies the In predicate on the "download" field.
func DownloadIsNil ¶
func DownloadIsNil() predicate.ProxyUserSubscribe
DownloadIsNil applies the IsNil predicate on the "download" field.
func DownloadLT ¶
func DownloadLT(v int64) predicate.ProxyUserSubscribe
DownloadLT applies the LT predicate on the "download" field.
func DownloadLTE ¶
func DownloadLTE(v int64) predicate.ProxyUserSubscribe
DownloadLTE applies the LTE predicate on the "download" field.
func DownloadNEQ ¶
func DownloadNEQ(v int64) predicate.ProxyUserSubscribe
DownloadNEQ applies the NEQ predicate on the "download" field.
func DownloadNotIn ¶
func DownloadNotIn(vs ...int64) predicate.ProxyUserSubscribe
DownloadNotIn applies the NotIn predicate on the "download" field.
func DownloadNotNil ¶
func DownloadNotNil() predicate.ProxyUserSubscribe
DownloadNotNil applies the NotNil predicate on the "download" field.
func ExpireTime ¶
func ExpireTime(v time.Time) predicate.ProxyUserSubscribe
ExpireTime applies equality check predicate on the "expire_time" field. It's identical to ExpireTimeEQ.
func ExpireTimeEQ ¶
func ExpireTimeEQ(v time.Time) predicate.ProxyUserSubscribe
ExpireTimeEQ applies the EQ predicate on the "expire_time" field.
func ExpireTimeGT ¶
func ExpireTimeGT(v time.Time) predicate.ProxyUserSubscribe
ExpireTimeGT applies the GT predicate on the "expire_time" field.
func ExpireTimeGTE ¶
func ExpireTimeGTE(v time.Time) predicate.ProxyUserSubscribe
ExpireTimeGTE applies the GTE predicate on the "expire_time" field.
func ExpireTimeIn ¶
func ExpireTimeIn(vs ...time.Time) predicate.ProxyUserSubscribe
ExpireTimeIn applies the In predicate on the "expire_time" field.
func ExpireTimeIsNil ¶
func ExpireTimeIsNil() predicate.ProxyUserSubscribe
ExpireTimeIsNil applies the IsNil predicate on the "expire_time" field.
func ExpireTimeLT ¶
func ExpireTimeLT(v time.Time) predicate.ProxyUserSubscribe
ExpireTimeLT applies the LT predicate on the "expire_time" field.
func ExpireTimeLTE ¶
func ExpireTimeLTE(v time.Time) predicate.ProxyUserSubscribe
ExpireTimeLTE applies the LTE predicate on the "expire_time" field.
func ExpireTimeNEQ ¶
func ExpireTimeNEQ(v time.Time) predicate.ProxyUserSubscribe
ExpireTimeNEQ applies the NEQ predicate on the "expire_time" field.
func ExpireTimeNotIn ¶
func ExpireTimeNotIn(vs ...time.Time) predicate.ProxyUserSubscribe
ExpireTimeNotIn applies the NotIn predicate on the "expire_time" field.
func ExpireTimeNotNil ¶
func ExpireTimeNotNil() predicate.ProxyUserSubscribe
ExpireTimeNotNil applies the NotNil predicate on the "expire_time" field.
func ExpiredDownload ¶
func ExpiredDownload(v int64) predicate.ProxyUserSubscribe
ExpiredDownload applies equality check predicate on the "expired_download" field. It's identical to ExpiredDownloadEQ.
func ExpiredDownloadEQ ¶
func ExpiredDownloadEQ(v int64) predicate.ProxyUserSubscribe
ExpiredDownloadEQ applies the EQ predicate on the "expired_download" field.
func ExpiredDownloadGT ¶
func ExpiredDownloadGT(v int64) predicate.ProxyUserSubscribe
ExpiredDownloadGT applies the GT predicate on the "expired_download" field.
func ExpiredDownloadGTE ¶
func ExpiredDownloadGTE(v int64) predicate.ProxyUserSubscribe
ExpiredDownloadGTE applies the GTE predicate on the "expired_download" field.
func ExpiredDownloadIn ¶
func ExpiredDownloadIn(vs ...int64) predicate.ProxyUserSubscribe
ExpiredDownloadIn applies the In predicate on the "expired_download" field.
func ExpiredDownloadIsNil ¶
func ExpiredDownloadIsNil() predicate.ProxyUserSubscribe
ExpiredDownloadIsNil applies the IsNil predicate on the "expired_download" field.
func ExpiredDownloadLT ¶
func ExpiredDownloadLT(v int64) predicate.ProxyUserSubscribe
ExpiredDownloadLT applies the LT predicate on the "expired_download" field.
func ExpiredDownloadLTE ¶
func ExpiredDownloadLTE(v int64) predicate.ProxyUserSubscribe
ExpiredDownloadLTE applies the LTE predicate on the "expired_download" field.
func ExpiredDownloadNEQ ¶
func ExpiredDownloadNEQ(v int64) predicate.ProxyUserSubscribe
ExpiredDownloadNEQ applies the NEQ predicate on the "expired_download" field.
func ExpiredDownloadNotIn ¶
func ExpiredDownloadNotIn(vs ...int64) predicate.ProxyUserSubscribe
ExpiredDownloadNotIn applies the NotIn predicate on the "expired_download" field.
func ExpiredDownloadNotNil ¶
func ExpiredDownloadNotNil() predicate.ProxyUserSubscribe
ExpiredDownloadNotNil applies the NotNil predicate on the "expired_download" field.
func ExpiredUpload ¶
func ExpiredUpload(v int64) predicate.ProxyUserSubscribe
ExpiredUpload applies equality check predicate on the "expired_upload" field. It's identical to ExpiredUploadEQ.
func ExpiredUploadEQ ¶
func ExpiredUploadEQ(v int64) predicate.ProxyUserSubscribe
ExpiredUploadEQ applies the EQ predicate on the "expired_upload" field.
func ExpiredUploadGT ¶
func ExpiredUploadGT(v int64) predicate.ProxyUserSubscribe
ExpiredUploadGT applies the GT predicate on the "expired_upload" field.
func ExpiredUploadGTE ¶
func ExpiredUploadGTE(v int64) predicate.ProxyUserSubscribe
ExpiredUploadGTE applies the GTE predicate on the "expired_upload" field.
func ExpiredUploadIn ¶
func ExpiredUploadIn(vs ...int64) predicate.ProxyUserSubscribe
ExpiredUploadIn applies the In predicate on the "expired_upload" field.
func ExpiredUploadIsNil ¶
func ExpiredUploadIsNil() predicate.ProxyUserSubscribe
ExpiredUploadIsNil applies the IsNil predicate on the "expired_upload" field.
func ExpiredUploadLT ¶
func ExpiredUploadLT(v int64) predicate.ProxyUserSubscribe
ExpiredUploadLT applies the LT predicate on the "expired_upload" field.
func ExpiredUploadLTE ¶
func ExpiredUploadLTE(v int64) predicate.ProxyUserSubscribe
ExpiredUploadLTE applies the LTE predicate on the "expired_upload" field.
func ExpiredUploadNEQ ¶
func ExpiredUploadNEQ(v int64) predicate.ProxyUserSubscribe
ExpiredUploadNEQ applies the NEQ predicate on the "expired_upload" field.
func ExpiredUploadNotIn ¶
func ExpiredUploadNotIn(vs ...int64) predicate.ProxyUserSubscribe
ExpiredUploadNotIn applies the NotIn predicate on the "expired_upload" field.
func ExpiredUploadNotNil ¶
func ExpiredUploadNotNil() predicate.ProxyUserSubscribe
ExpiredUploadNotNil applies the NotNil predicate on the "expired_upload" field.
func FinishedAt ¶
func FinishedAt(v time.Time) predicate.ProxyUserSubscribe
FinishedAt applies equality check predicate on the "finished_at" field. It's identical to FinishedAtEQ.
func FinishedAtEQ ¶
func FinishedAtEQ(v time.Time) predicate.ProxyUserSubscribe
FinishedAtEQ applies the EQ predicate on the "finished_at" field.
func FinishedAtGT ¶
func FinishedAtGT(v time.Time) predicate.ProxyUserSubscribe
FinishedAtGT applies the GT predicate on the "finished_at" field.
func FinishedAtGTE ¶
func FinishedAtGTE(v time.Time) predicate.ProxyUserSubscribe
FinishedAtGTE applies the GTE predicate on the "finished_at" field.
func FinishedAtIn ¶
func FinishedAtIn(vs ...time.Time) predicate.ProxyUserSubscribe
FinishedAtIn applies the In predicate on the "finished_at" field.
func FinishedAtIsNil ¶
func FinishedAtIsNil() predicate.ProxyUserSubscribe
FinishedAtIsNil applies the IsNil predicate on the "finished_at" field.
func FinishedAtLT ¶
func FinishedAtLT(v time.Time) predicate.ProxyUserSubscribe
FinishedAtLT applies the LT predicate on the "finished_at" field.
func FinishedAtLTE ¶
func FinishedAtLTE(v time.Time) predicate.ProxyUserSubscribe
FinishedAtLTE applies the LTE predicate on the "finished_at" field.
func FinishedAtNEQ ¶
func FinishedAtNEQ(v time.Time) predicate.ProxyUserSubscribe
FinishedAtNEQ applies the NEQ predicate on the "finished_at" field.
func FinishedAtNotIn ¶
func FinishedAtNotIn(vs ...time.Time) predicate.ProxyUserSubscribe
FinishedAtNotIn applies the NotIn predicate on the "finished_at" field.
func FinishedAtNotNil ¶
func FinishedAtNotNil() predicate.ProxyUserSubscribe
FinishedAtNotNil applies the NotNil predicate on the "finished_at" field.
func GroupLocked ¶
func GroupLocked(v bool) predicate.ProxyUserSubscribe
GroupLocked applies equality check predicate on the "group_locked" field. It's identical to GroupLockedEQ.
func GroupLockedEQ ¶
func GroupLockedEQ(v bool) predicate.ProxyUserSubscribe
GroupLockedEQ applies the EQ predicate on the "group_locked" field.
func GroupLockedNEQ ¶
func GroupLockedNEQ(v bool) predicate.ProxyUserSubscribe
GroupLockedNEQ applies the NEQ predicate on the "group_locked" field.
func ID ¶
func ID(id int64) predicate.ProxyUserSubscribe
ID filters vertices based on their ID field.
func IDEQ ¶
func IDEQ(id int64) predicate.ProxyUserSubscribe
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id int64) predicate.ProxyUserSubscribe
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id int64) predicate.ProxyUserSubscribe
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...int64) predicate.ProxyUserSubscribe
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id int64) predicate.ProxyUserSubscribe
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id int64) predicate.ProxyUserSubscribe
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id int64) predicate.ProxyUserSubscribe
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...int64) predicate.ProxyUserSubscribe
IDNotIn applies the NotIn predicate on the ID field.
func NodeGroupID ¶
func NodeGroupID(v int64) predicate.ProxyUserSubscribe
NodeGroupID applies equality check predicate on the "node_group_id" field. It's identical to NodeGroupIDEQ.
func NodeGroupIDEQ ¶
func NodeGroupIDEQ(v int64) predicate.ProxyUserSubscribe
NodeGroupIDEQ applies the EQ predicate on the "node_group_id" field.
func NodeGroupIDGT ¶
func NodeGroupIDGT(v int64) predicate.ProxyUserSubscribe
NodeGroupIDGT applies the GT predicate on the "node_group_id" field.
func NodeGroupIDGTE ¶
func NodeGroupIDGTE(v int64) predicate.ProxyUserSubscribe
NodeGroupIDGTE applies the GTE predicate on the "node_group_id" field.
func NodeGroupIDIn ¶
func NodeGroupIDIn(vs ...int64) predicate.ProxyUserSubscribe
NodeGroupIDIn applies the In predicate on the "node_group_id" field.
func NodeGroupIDLT ¶
func NodeGroupIDLT(v int64) predicate.ProxyUserSubscribe
NodeGroupIDLT applies the LT predicate on the "node_group_id" field.
func NodeGroupIDLTE ¶
func NodeGroupIDLTE(v int64) predicate.ProxyUserSubscribe
NodeGroupIDLTE applies the LTE predicate on the "node_group_id" field.
func NodeGroupIDNEQ ¶
func NodeGroupIDNEQ(v int64) predicate.ProxyUserSubscribe
NodeGroupIDNEQ applies the NEQ predicate on the "node_group_id" field.
func NodeGroupIDNotIn ¶
func NodeGroupIDNotIn(vs ...int64) predicate.ProxyUserSubscribe
NodeGroupIDNotIn applies the NotIn predicate on the "node_group_id" field.
func Not ¶
func Not(p predicate.ProxyUserSubscribe) predicate.ProxyUserSubscribe
Not applies the not operator on the given predicate.
func Note ¶
func Note(v string) predicate.ProxyUserSubscribe
Note applies equality check predicate on the "note" field. It's identical to NoteEQ.
func NoteContains ¶
func NoteContains(v string) predicate.ProxyUserSubscribe
NoteContains applies the Contains predicate on the "note" field.
func NoteContainsFold ¶
func NoteContainsFold(v string) predicate.ProxyUserSubscribe
NoteContainsFold applies the ContainsFold predicate on the "note" field.
func NoteEQ ¶
func NoteEQ(v string) predicate.ProxyUserSubscribe
NoteEQ applies the EQ predicate on the "note" field.
func NoteEqualFold ¶
func NoteEqualFold(v string) predicate.ProxyUserSubscribe
NoteEqualFold applies the EqualFold predicate on the "note" field.
func NoteGT ¶
func NoteGT(v string) predicate.ProxyUserSubscribe
NoteGT applies the GT predicate on the "note" field.
func NoteGTE ¶
func NoteGTE(v string) predicate.ProxyUserSubscribe
NoteGTE applies the GTE predicate on the "note" field.
func NoteHasPrefix ¶
func NoteHasPrefix(v string) predicate.ProxyUserSubscribe
NoteHasPrefix applies the HasPrefix predicate on the "note" field.
func NoteHasSuffix ¶
func NoteHasSuffix(v string) predicate.ProxyUserSubscribe
NoteHasSuffix applies the HasSuffix predicate on the "note" field.
func NoteIn ¶
func NoteIn(vs ...string) predicate.ProxyUserSubscribe
NoteIn applies the In predicate on the "note" field.
func NoteIsNil ¶
func NoteIsNil() predicate.ProxyUserSubscribe
NoteIsNil applies the IsNil predicate on the "note" field.
func NoteLT ¶
func NoteLT(v string) predicate.ProxyUserSubscribe
NoteLT applies the LT predicate on the "note" field.
func NoteLTE ¶
func NoteLTE(v string) predicate.ProxyUserSubscribe
NoteLTE applies the LTE predicate on the "note" field.
func NoteNEQ ¶
func NoteNEQ(v string) predicate.ProxyUserSubscribe
NoteNEQ applies the NEQ predicate on the "note" field.
func NoteNotIn ¶
func NoteNotIn(vs ...string) predicate.ProxyUserSubscribe
NoteNotIn applies the NotIn predicate on the "note" field.
func NoteNotNil ¶
func NoteNotNil() predicate.ProxyUserSubscribe
NoteNotNil applies the NotNil predicate on the "note" field.
func Or ¶
func Or(predicates ...predicate.ProxyUserSubscribe) predicate.ProxyUserSubscribe
Or groups predicates with the OR operator between them.
func OrderID ¶
func OrderID(v int64) predicate.ProxyUserSubscribe
OrderID applies equality check predicate on the "order_id" field. It's identical to OrderIDEQ.
func OrderIDEQ ¶
func OrderIDEQ(v int64) predicate.ProxyUserSubscribe
OrderIDEQ applies the EQ predicate on the "order_id" field.
func OrderIDGT ¶
func OrderIDGT(v int64) predicate.ProxyUserSubscribe
OrderIDGT applies the GT predicate on the "order_id" field.
func OrderIDGTE ¶
func OrderIDGTE(v int64) predicate.ProxyUserSubscribe
OrderIDGTE applies the GTE predicate on the "order_id" field.
func OrderIDIn ¶
func OrderIDIn(vs ...int64) predicate.ProxyUserSubscribe
OrderIDIn applies the In predicate on the "order_id" field.
func OrderIDLT ¶
func OrderIDLT(v int64) predicate.ProxyUserSubscribe
OrderIDLT applies the LT predicate on the "order_id" field.
func OrderIDLTE ¶
func OrderIDLTE(v int64) predicate.ProxyUserSubscribe
OrderIDLTE applies the LTE predicate on the "order_id" field.
func OrderIDNEQ ¶
func OrderIDNEQ(v int64) predicate.ProxyUserSubscribe
OrderIDNEQ applies the NEQ predicate on the "order_id" field.
func OrderIDNotIn ¶
func OrderIDNotIn(vs ...int64) predicate.ProxyUserSubscribe
OrderIDNotIn applies the NotIn predicate on the "order_id" field.
func StartTime ¶
func StartTime(v time.Time) predicate.ProxyUserSubscribe
StartTime applies equality check predicate on the "start_time" field. It's identical to StartTimeEQ.
func StartTimeEQ ¶
func StartTimeEQ(v time.Time) predicate.ProxyUserSubscribe
StartTimeEQ applies the EQ predicate on the "start_time" field.
func StartTimeGT ¶
func StartTimeGT(v time.Time) predicate.ProxyUserSubscribe
StartTimeGT applies the GT predicate on the "start_time" field.
func StartTimeGTE ¶
func StartTimeGTE(v time.Time) predicate.ProxyUserSubscribe
StartTimeGTE applies the GTE predicate on the "start_time" field.
func StartTimeIn ¶
func StartTimeIn(vs ...time.Time) predicate.ProxyUserSubscribe
StartTimeIn applies the In predicate on the "start_time" field.
func StartTimeLT ¶
func StartTimeLT(v time.Time) predicate.ProxyUserSubscribe
StartTimeLT applies the LT predicate on the "start_time" field.
func StartTimeLTE ¶
func StartTimeLTE(v time.Time) predicate.ProxyUserSubscribe
StartTimeLTE applies the LTE predicate on the "start_time" field.
func StartTimeNEQ ¶
func StartTimeNEQ(v time.Time) predicate.ProxyUserSubscribe
StartTimeNEQ applies the NEQ predicate on the "start_time" field.
func StartTimeNotIn ¶
func StartTimeNotIn(vs ...time.Time) predicate.ProxyUserSubscribe
StartTimeNotIn applies the NotIn predicate on the "start_time" field.
func Status ¶
func Status(v int8) predicate.ProxyUserSubscribe
Status applies equality check predicate on the "status" field. It's identical to StatusEQ.
func StatusEQ ¶
func StatusEQ(v int8) predicate.ProxyUserSubscribe
StatusEQ applies the EQ predicate on the "status" field.
func StatusGT ¶
func StatusGT(v int8) predicate.ProxyUserSubscribe
StatusGT applies the GT predicate on the "status" field.
func StatusGTE ¶
func StatusGTE(v int8) predicate.ProxyUserSubscribe
StatusGTE applies the GTE predicate on the "status" field.
func StatusIn ¶
func StatusIn(vs ...int8) predicate.ProxyUserSubscribe
StatusIn applies the In predicate on the "status" field.
func StatusIsNil ¶
func StatusIsNil() predicate.ProxyUserSubscribe
StatusIsNil applies the IsNil predicate on the "status" field.
func StatusLT ¶
func StatusLT(v int8) predicate.ProxyUserSubscribe
StatusLT applies the LT predicate on the "status" field.
func StatusLTE ¶
func StatusLTE(v int8) predicate.ProxyUserSubscribe
StatusLTE applies the LTE predicate on the "status" field.
func StatusNEQ ¶
func StatusNEQ(v int8) predicate.ProxyUserSubscribe
StatusNEQ applies the NEQ predicate on the "status" field.
func StatusNotIn ¶
func StatusNotIn(vs ...int8) predicate.ProxyUserSubscribe
StatusNotIn applies the NotIn predicate on the "status" field.
func StatusNotNil ¶
func StatusNotNil() predicate.ProxyUserSubscribe
StatusNotNil applies the NotNil predicate on the "status" field.
func SubscribeID ¶
func SubscribeID(v int64) predicate.ProxyUserSubscribe
SubscribeID applies equality check predicate on the "subscribe_id" field. It's identical to SubscribeIDEQ.
func SubscribeIDEQ ¶
func SubscribeIDEQ(v int64) predicate.ProxyUserSubscribe
SubscribeIDEQ applies the EQ predicate on the "subscribe_id" field.
func SubscribeIDGT ¶
func SubscribeIDGT(v int64) predicate.ProxyUserSubscribe
SubscribeIDGT applies the GT predicate on the "subscribe_id" field.
func SubscribeIDGTE ¶
func SubscribeIDGTE(v int64) predicate.ProxyUserSubscribe
SubscribeIDGTE applies the GTE predicate on the "subscribe_id" field.
func SubscribeIDIn ¶
func SubscribeIDIn(vs ...int64) predicate.ProxyUserSubscribe
SubscribeIDIn applies the In predicate on the "subscribe_id" field.
func SubscribeIDLT ¶
func SubscribeIDLT(v int64) predicate.ProxyUserSubscribe
SubscribeIDLT applies the LT predicate on the "subscribe_id" field.
func SubscribeIDLTE ¶
func SubscribeIDLTE(v int64) predicate.ProxyUserSubscribe
SubscribeIDLTE applies the LTE predicate on the "subscribe_id" field.
func SubscribeIDNEQ ¶
func SubscribeIDNEQ(v int64) predicate.ProxyUserSubscribe
SubscribeIDNEQ applies the NEQ predicate on the "subscribe_id" field.
func SubscribeIDNotIn ¶
func SubscribeIDNotIn(vs ...int64) predicate.ProxyUserSubscribe
SubscribeIDNotIn applies the NotIn predicate on the "subscribe_id" field.
func Token ¶
func Token(v string) predicate.ProxyUserSubscribe
Token applies equality check predicate on the "token" field. It's identical to TokenEQ.
func TokenContains ¶
func TokenContains(v string) predicate.ProxyUserSubscribe
TokenContains applies the Contains predicate on the "token" field.
func TokenContainsFold ¶
func TokenContainsFold(v string) predicate.ProxyUserSubscribe
TokenContainsFold applies the ContainsFold predicate on the "token" field.
func TokenEQ ¶
func TokenEQ(v string) predicate.ProxyUserSubscribe
TokenEQ applies the EQ predicate on the "token" field.
func TokenEqualFold ¶
func TokenEqualFold(v string) predicate.ProxyUserSubscribe
TokenEqualFold applies the EqualFold predicate on the "token" field.
func TokenGT ¶
func TokenGT(v string) predicate.ProxyUserSubscribe
TokenGT applies the GT predicate on the "token" field.
func TokenGTE ¶
func TokenGTE(v string) predicate.ProxyUserSubscribe
TokenGTE applies the GTE predicate on the "token" field.
func TokenHasPrefix ¶
func TokenHasPrefix(v string) predicate.ProxyUserSubscribe
TokenHasPrefix applies the HasPrefix predicate on the "token" field.
func TokenHasSuffix ¶
func TokenHasSuffix(v string) predicate.ProxyUserSubscribe
TokenHasSuffix applies the HasSuffix predicate on the "token" field.
func TokenIn ¶
func TokenIn(vs ...string) predicate.ProxyUserSubscribe
TokenIn applies the In predicate on the "token" field.
func TokenIsNil ¶
func TokenIsNil() predicate.ProxyUserSubscribe
TokenIsNil applies the IsNil predicate on the "token" field.
func TokenLT ¶
func TokenLT(v string) predicate.ProxyUserSubscribe
TokenLT applies the LT predicate on the "token" field.
func TokenLTE ¶
func TokenLTE(v string) predicate.ProxyUserSubscribe
TokenLTE applies the LTE predicate on the "token" field.
func TokenNEQ ¶
func TokenNEQ(v string) predicate.ProxyUserSubscribe
TokenNEQ applies the NEQ predicate on the "token" field.
func TokenNotIn ¶
func TokenNotIn(vs ...string) predicate.ProxyUserSubscribe
TokenNotIn applies the NotIn predicate on the "token" field.
func TokenNotNil ¶
func TokenNotNil() predicate.ProxyUserSubscribe
TokenNotNil applies the NotNil predicate on the "token" field.
func Traffic ¶
func Traffic(v int64) predicate.ProxyUserSubscribe
Traffic applies equality check predicate on the "traffic" field. It's identical to TrafficEQ.
func TrafficEQ ¶
func TrafficEQ(v int64) predicate.ProxyUserSubscribe
TrafficEQ applies the EQ predicate on the "traffic" field.
func TrafficGT ¶
func TrafficGT(v int64) predicate.ProxyUserSubscribe
TrafficGT applies the GT predicate on the "traffic" field.
func TrafficGTE ¶
func TrafficGTE(v int64) predicate.ProxyUserSubscribe
TrafficGTE applies the GTE predicate on the "traffic" field.
func TrafficIn ¶
func TrafficIn(vs ...int64) predicate.ProxyUserSubscribe
TrafficIn applies the In predicate on the "traffic" field.
func TrafficIsNil ¶
func TrafficIsNil() predicate.ProxyUserSubscribe
TrafficIsNil applies the IsNil predicate on the "traffic" field.
func TrafficLT ¶
func TrafficLT(v int64) predicate.ProxyUserSubscribe
TrafficLT applies the LT predicate on the "traffic" field.
func TrafficLTE ¶
func TrafficLTE(v int64) predicate.ProxyUserSubscribe
TrafficLTE applies the LTE predicate on the "traffic" field.
func TrafficNEQ ¶
func TrafficNEQ(v int64) predicate.ProxyUserSubscribe
TrafficNEQ applies the NEQ predicate on the "traffic" field.
func TrafficNotIn ¶
func TrafficNotIn(vs ...int64) predicate.ProxyUserSubscribe
TrafficNotIn applies the NotIn predicate on the "traffic" field.
func TrafficNotNil ¶
func TrafficNotNil() predicate.ProxyUserSubscribe
TrafficNotNil applies the NotNil predicate on the "traffic" field.
func UUID ¶
func UUID(v string) predicate.ProxyUserSubscribe
UUID applies equality check predicate on the "uuid" field. It's identical to UUIDEQ.
func UUIDContains ¶
func UUIDContains(v string) predicate.ProxyUserSubscribe
UUIDContains applies the Contains predicate on the "uuid" field.
func UUIDContainsFold ¶
func UUIDContainsFold(v string) predicate.ProxyUserSubscribe
UUIDContainsFold applies the ContainsFold predicate on the "uuid" field.
func UUIDEQ ¶
func UUIDEQ(v string) predicate.ProxyUserSubscribe
UUIDEQ applies the EQ predicate on the "uuid" field.
func UUIDEqualFold ¶
func UUIDEqualFold(v string) predicate.ProxyUserSubscribe
UUIDEqualFold applies the EqualFold predicate on the "uuid" field.
func UUIDGT ¶
func UUIDGT(v string) predicate.ProxyUserSubscribe
UUIDGT applies the GT predicate on the "uuid" field.
func UUIDGTE ¶
func UUIDGTE(v string) predicate.ProxyUserSubscribe
UUIDGTE applies the GTE predicate on the "uuid" field.
func UUIDHasPrefix ¶
func UUIDHasPrefix(v string) predicate.ProxyUserSubscribe
UUIDHasPrefix applies the HasPrefix predicate on the "uuid" field.
func UUIDHasSuffix ¶
func UUIDHasSuffix(v string) predicate.ProxyUserSubscribe
UUIDHasSuffix applies the HasSuffix predicate on the "uuid" field.
func UUIDIn ¶
func UUIDIn(vs ...string) predicate.ProxyUserSubscribe
UUIDIn applies the In predicate on the "uuid" field.
func UUIDIsNil ¶
func UUIDIsNil() predicate.ProxyUserSubscribe
UUIDIsNil applies the IsNil predicate on the "uuid" field.
func UUIDLT ¶
func UUIDLT(v string) predicate.ProxyUserSubscribe
UUIDLT applies the LT predicate on the "uuid" field.
func UUIDLTE ¶
func UUIDLTE(v string) predicate.ProxyUserSubscribe
UUIDLTE applies the LTE predicate on the "uuid" field.
func UUIDNEQ ¶
func UUIDNEQ(v string) predicate.ProxyUserSubscribe
UUIDNEQ applies the NEQ predicate on the "uuid" field.
func UUIDNotIn ¶
func UUIDNotIn(vs ...string) predicate.ProxyUserSubscribe
UUIDNotIn applies the NotIn predicate on the "uuid" field.
func UUIDNotNil ¶
func UUIDNotNil() predicate.ProxyUserSubscribe
UUIDNotNil applies the NotNil predicate on the "uuid" field.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.ProxyUserSubscribe
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.ProxyUserSubscribe
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.ProxyUserSubscribe
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.ProxyUserSubscribe
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.ProxyUserSubscribe
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.ProxyUserSubscribe
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.ProxyUserSubscribe
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.ProxyUserSubscribe
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.ProxyUserSubscribe
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func Upload ¶
func Upload(v int64) predicate.ProxyUserSubscribe
Upload applies equality check predicate on the "upload" field. It's identical to UploadEQ.
func UploadEQ ¶
func UploadEQ(v int64) predicate.ProxyUserSubscribe
UploadEQ applies the EQ predicate on the "upload" field.
func UploadGT ¶
func UploadGT(v int64) predicate.ProxyUserSubscribe
UploadGT applies the GT predicate on the "upload" field.
func UploadGTE ¶
func UploadGTE(v int64) predicate.ProxyUserSubscribe
UploadGTE applies the GTE predicate on the "upload" field.
func UploadIn ¶
func UploadIn(vs ...int64) predicate.ProxyUserSubscribe
UploadIn applies the In predicate on the "upload" field.
func UploadIsNil ¶
func UploadIsNil() predicate.ProxyUserSubscribe
UploadIsNil applies the IsNil predicate on the "upload" field.
func UploadLT ¶
func UploadLT(v int64) predicate.ProxyUserSubscribe
UploadLT applies the LT predicate on the "upload" field.
func UploadLTE ¶
func UploadLTE(v int64) predicate.ProxyUserSubscribe
UploadLTE applies the LTE predicate on the "upload" field.
func UploadNEQ ¶
func UploadNEQ(v int64) predicate.ProxyUserSubscribe
UploadNEQ applies the NEQ predicate on the "upload" field.
func UploadNotIn ¶
func UploadNotIn(vs ...int64) predicate.ProxyUserSubscribe
UploadNotIn applies the NotIn predicate on the "upload" field.
func UploadNotNil ¶
func UploadNotNil() predicate.ProxyUserSubscribe
UploadNotNil applies the NotNil predicate on the "upload" field.
func UserID ¶
func UserID(v int64) predicate.ProxyUserSubscribe
UserID applies equality check predicate on the "user_id" field. It's identical to UserIDEQ.
func UserIDEQ ¶
func UserIDEQ(v int64) predicate.ProxyUserSubscribe
UserIDEQ applies the EQ predicate on the "user_id" field.
func UserIDGT ¶
func UserIDGT(v int64) predicate.ProxyUserSubscribe
UserIDGT applies the GT predicate on the "user_id" field.
func UserIDGTE ¶
func UserIDGTE(v int64) predicate.ProxyUserSubscribe
UserIDGTE applies the GTE predicate on the "user_id" field.
func UserIDIn ¶
func UserIDIn(vs ...int64) predicate.ProxyUserSubscribe
UserIDIn applies the In predicate on the "user_id" field.
func UserIDLT ¶
func UserIDLT(v int64) predicate.ProxyUserSubscribe
UserIDLT applies the LT predicate on the "user_id" field.
func UserIDLTE ¶
func UserIDLTE(v int64) predicate.ProxyUserSubscribe
UserIDLTE applies the LTE predicate on the "user_id" field.
func UserIDNEQ ¶
func UserIDNEQ(v int64) predicate.ProxyUserSubscribe
UserIDNEQ applies the NEQ predicate on the "user_id" field.
func UserIDNotIn ¶
func UserIDNotIn(vs ...int64) predicate.ProxyUserSubscribe
UserIDNotIn applies the NotIn predicate on the "user_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the ProxyUserSubscribe queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByDownload ¶
func ByDownload(opts ...sql.OrderTermOption) OrderOption
ByDownload orders the results by the download field.
func ByExpireTime ¶
func ByExpireTime(opts ...sql.OrderTermOption) OrderOption
ByExpireTime orders the results by the expire_time field.
func ByExpiredDownload ¶
func ByExpiredDownload(opts ...sql.OrderTermOption) OrderOption
ByExpiredDownload orders the results by the expired_download field.
func ByExpiredUpload ¶
func ByExpiredUpload(opts ...sql.OrderTermOption) OrderOption
ByExpiredUpload orders the results by the expired_upload field.
func ByFinishedAt ¶
func ByFinishedAt(opts ...sql.OrderTermOption) OrderOption
ByFinishedAt orders the results by the finished_at field.
func ByGroupLocked ¶
func ByGroupLocked(opts ...sql.OrderTermOption) OrderOption
ByGroupLocked orders the results by the group_locked field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByNodeGroupID ¶
func ByNodeGroupID(opts ...sql.OrderTermOption) OrderOption
ByNodeGroupID orders the results by the node_group_id field.
func ByNote ¶
func ByNote(opts ...sql.OrderTermOption) OrderOption
ByNote orders the results by the note field.
func ByOrderID ¶
func ByOrderID(opts ...sql.OrderTermOption) OrderOption
ByOrderID orders the results by the order_id field.
func ByStartTime ¶
func ByStartTime(opts ...sql.OrderTermOption) OrderOption
ByStartTime orders the results by the start_time field.
func ByStatus ¶
func ByStatus(opts ...sql.OrderTermOption) OrderOption
ByStatus orders the results by the status field.
func BySubscribeID ¶
func BySubscribeID(opts ...sql.OrderTermOption) OrderOption
BySubscribeID orders the results by the subscribe_id field.
func ByToken ¶
func ByToken(opts ...sql.OrderTermOption) OrderOption
ByToken orders the results by the token field.
func ByTraffic ¶
func ByTraffic(opts ...sql.OrderTermOption) OrderOption
ByTraffic orders the results by the traffic field.
func ByUUID ¶
func ByUUID(opts ...sql.OrderTermOption) OrderOption
ByUUID orders the results by the uuid field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpload ¶
func ByUpload(opts ...sql.OrderTermOption) OrderOption
ByUpload orders the results by the upload field.
func ByUserID ¶
func ByUserID(opts ...sql.OrderTermOption) OrderOption
ByUserID orders the results by the user_id field.