Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CloseOnExec ¶
CloseOnExec makes sure closing the file on process forking
func TempFileWithText ¶
TempFileWithText creates the temporary file with the given content, and returns the opened *os.File instance The file is kept as open, the caller should close the file handle, and remove the file by name
func TempFilenameWithText ¶
TempFilenameWithText creates the file with the given content, and returns the filename (full path) The caller should remove the file after use
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.