httpform

package
v1.0.11 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 28, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FirstNonEmpty

func FirstNonEmpty(values url.Values, keys ...string) string

func ParseGETBodyForm

func ParseGETBodyForm(r *http.Request) (url.Values, error)

ParseGETBodyForm parses x-www-form-urlencoded style payloads from GET request bodies. net/http only parses URL query strings for GET requests, so legacy clients that incorrectly place form fields in the body need this compatibility fallback.

func StringSlice

func StringSlice(values url.Values, keys ...string) []string

Types

This section is empty.

Jump to